@@ -20,8 +20,10 @@
 #include "Lucy/Util/ToolSet.h"
 
 #include "Lucy/Analysis/Normalizer.h"
+#include "Clownfish/Boolean.h"
 #include "Lucy/Analysis/Token.h"
 #include "Lucy/Analysis/Inversion.h"
+#include "Lucy/Util/Json.h"
 
 #include "utf8proc.h"
 
@@ -135,10 +137,10 @@ Normalizer_Dump_IMP(Normalizer *self) {
 
     Hash_Store_Utf8(dump, "normalization_form", 18, (Obj*)form);
 
-    BoolNum *case_fold = Bool_singleton(!!(options & UTF8PROC_CASEFOLD));
+    Boolean *case_fold = Bool_singleton(!!(options & UTF8PROC_CASEFOLD));
     Hash_Store_Utf8(dump, "case_fold", 9, (Obj*)case_fold);
 
-    BoolNum *strip_accents = Bool_singleton(!!(options & UTF8PROC_STRIPMARK));
+    Boolean *strip_accents = Bool_singleton(!!(options & UTF8PROC_STRIPMARK));
     Hash_Store_Utf8(dump, "strip_accents", 13, (Obj*)strip_accents);
 
     return dump;
@@ -154,9 +156,9 @@ Normalizer_Load_IMP(Normalizer *self, Obj *dump) {
     Obj *obj = Hash_Fetch_Utf8(source, "normalization_form", 18);
     String *form = (String*)CERTIFY(obj, STRING);
     obj = Hash_Fetch_Utf8(source, "case_fold", 9);
-    bool case_fold = Obj_To_Bool(CERTIFY(obj, OBJ));
+    bool case_fold = Json_obj_to_bool(CERTIFY(obj, OBJ));
     obj = Hash_Fetch_Utf8(source, "strip_accents", 13);
-    bool strip_accents = Obj_To_Bool(CERTIFY(obj, OBJ));
+    bool strip_accents = Json_obj_to_bool(CERTIFY(obj, OBJ));
 
     return Normalizer_init(loaded, form, case_fold, strip_accents);
 }
@@ -164,7 +166,7 @@ Normalizer_Load_IMP(Normalizer *self, Obj *dump) {
 bool
 Normalizer_Equals_IMP(Normalizer *self, Obj *other) {
     if ((Normalizer*)other == self)       { return true; }
-    if (!Obj_Is_A(other, NORMALIZER))     { return false; }
+    if (!Obj_is_a(other, NORMALIZER))     { return false; }
     NormalizerIVARS *const ivars = Normalizer_IVARS(self);
     NormalizerIVARS *const ovars = Normalizer_IVARS((Normalizer*)other);
     if (ovars->options != ivars->options) { return false; }
