@@ -26,28 +26,28 @@
 #include "Lucy/Util/Freezer.h"
 
 PolyAnalyzer*
-PolyAnalyzer_new(String *language, VArray *analyzers) {
+PolyAnalyzer_new(String *language, Vector *analyzers) {
     PolyAnalyzer *self = (PolyAnalyzer*)Class_Make_Obj(POLYANALYZER);
     return PolyAnalyzer_init(self, language, analyzers);
 }
 
 PolyAnalyzer*
 PolyAnalyzer_init(PolyAnalyzer *self, String *language,
-                  VArray *analyzers) {
+                  Vector *analyzers) {
     Analyzer_init((Analyzer*)self);
     PolyAnalyzerIVARS *const ivars = PolyAnalyzer_IVARS(self);
 
     if (analyzers) {
-        for (uint32_t i = 0, max = VA_Get_Size(analyzers); i < max; i++) {
-            CERTIFY(VA_Fetch(analyzers, i), ANALYZER);
+        for (uint32_t i = 0, max = Vec_Get_Size(analyzers); i < max; i++) {
+            CERTIFY(Vec_Fetch(analyzers, i), ANALYZER);
         }
-        ivars->analyzers = (VArray*)INCREF(analyzers);
+        ivars->analyzers = (Vector*)INCREF(analyzers);
     }
     else if (language) {
-        ivars->analyzers = VA_new(3);
-        VA_Push(ivars->analyzers, (Obj*)CaseFolder_new());
-        VA_Push(ivars->analyzers, (Obj*)RegexTokenizer_new(NULL));
-        VA_Push(ivars->analyzers, (Obj*)SnowStemmer_new(language));
+        ivars->analyzers = Vec_new(3);
+        Vec_Push(ivars->analyzers, (Obj*)CaseFolder_new());
+        Vec_Push(ivars->analyzers, (Obj*)RegexTokenizer_new(NULL));
+        Vec_Push(ivars->analyzers, (Obj*)SnowStemmer_new(language));
     }
     else {
         THROW(ERR, "Must specify either 'language' or 'analyzers'");
@@ -63,19 +63,19 @@ PolyAnalyzer_Destroy_IMP(PolyAnalyzer *self) {
     SUPER_DESTROY(self, POLYANALYZER);
 }
 
-VArray*
+Vector*
 PolyAnalyzer_Get_Analyzers_IMP(PolyAnalyzer *self) {
     return PolyAnalyzer_IVARS(self)->analyzers;
 }
 
 Inversion*
 PolyAnalyzer_Transform_IMP(PolyAnalyzer *self, Inversion *inversion) {
-    VArray *const analyzers = PolyAnalyzer_IVARS(self)->analyzers;
+    Vector *const analyzers = PolyAnalyzer_IVARS(self)->analyzers;
     (void)INCREF(inversion);
 
     // Iterate through each of the analyzers in order.
-    for (uint32_t i = 0, max = VA_Get_Size(analyzers); i < max; i++) {
-        Analyzer *analyzer = (Analyzer*)VA_Fetch(analyzers, i);
+    for (uint32_t i = 0, max = Vec_Get_Size(analyzers); i < max; i++) {
+        Analyzer *analyzer = (Analyzer*)Vec_Fetch(analyzers, i);
         Inversion *new_inversion = Analyzer_Transform(analyzer, inversion);
         DECREF(inversion);
         inversion = new_inversion;
@@ -86,8 +86,8 @@ PolyAnalyzer_Transform_IMP(PolyAnalyzer *self, Inversion *inversion) {
 
 Inversion*
 PolyAnalyzer_Transform_Text_IMP(PolyAnalyzer *self, String *text) {
-    VArray *const   analyzers     = PolyAnalyzer_IVARS(self)->analyzers;
-    const uint32_t  num_analyzers = VA_Get_Size(analyzers);
+    Vector *const   analyzers     = PolyAnalyzer_IVARS(self)->analyzers;
+    const uint32_t  num_analyzers = Vec_Get_Size(analyzers);
     Inversion      *retval;
 
     if (num_analyzers == 0) {
@@ -98,10 +98,10 @@ PolyAnalyzer_Transform_Text_IMP(PolyAnalyzer *self, String *text) {
         DECREF(seed);
     }
     else {
-        Analyzer *first_analyzer = (Analyzer*)VA_Fetch(analyzers, 0);
+        Analyzer *first_analyzer = (Analyzer*)Vec_Fetch(analyzers, 0);
         retval = Analyzer_Transform_Text(first_analyzer, text);
         for (uint32_t i = 1; i < num_analyzers; i++) {
-            Analyzer *analyzer = (Analyzer*)VA_Fetch(analyzers, i);
+            Analyzer *analyzer = (Analyzer*)Vec_Fetch(analyzers, i);
             Inversion *new_inversion = Analyzer_Transform(analyzer, retval);
             DECREF(retval);
             retval = new_inversion;
@@ -114,10 +114,10 @@ PolyAnalyzer_Transform_Text_IMP(PolyAnalyzer *self, String *text) {
 bool
 PolyAnalyzer_Equals_IMP(PolyAnalyzer *self, Obj *other) {
     if ((PolyAnalyzer*)other == self)                         { return true; }
-    if (!Obj_Is_A(other, POLYANALYZER))                       { return false; }
+    if (!Obj_is_a(other, POLYANALYZER))                       { return false; }
     PolyAnalyzerIVARS *const ivars = PolyAnalyzer_IVARS(self);
     PolyAnalyzerIVARS *const ovars = PolyAnalyzer_IVARS((PolyAnalyzer*)other);
-    if (!VA_Equals(ovars->analyzers, (Obj*)ivars->analyzers)) { return false; }
+    if (!Vec_Equals(ovars->analyzers, (Obj*)ivars->analyzers)) { return false; }
     return true;
 }
 
@@ -140,10 +140,10 @@ PolyAnalyzer_Load_IMP(PolyAnalyzer *self, Obj *dump) {
     PolyAnalyzer_Load_t super_load 
         = SUPER_METHOD_PTR(POLYANALYZER, LUCY_PolyAnalyzer_Load);
     PolyAnalyzer *loaded = super_load(self, dump);
-    VArray *analyzer_dumps
-        = (VArray*)CERTIFY(Hash_Fetch_Utf8(source, "analyzers", 9), VARRAY);
-    VArray *analyzers
-        = (VArray*)CERTIFY(Freezer_load((Obj*)analyzer_dumps), VARRAY);
+    Vector *analyzer_dumps
+        = (Vector*)CERTIFY(Hash_Fetch_Utf8(source, "analyzers", 9), VECTOR);
+    Vector *analyzers
+        = (Vector*)CERTIFY(Freezer_load((Obj*)analyzer_dumps), VECTOR);
     PolyAnalyzer_init(loaded, NULL, analyzers);
     DECREF(analyzers);
     return loaded;
