@@ -20,6 +20,7 @@
 #include <ctype.h>
 
 #include "Lucy/Analysis/SnowballStopFilter.h"
+#include "Clownfish/Boolean.h"
 #include "Lucy/Analysis/Token.h"
 #include "Lucy/Analysis/Inversion.h"
 #include "Lucy/Util/Freezer.h"
@@ -80,7 +81,7 @@ SnowStop_Transform_IMP(SnowballStopFilter *self, Inversion *inversion) {
 bool
 SnowStop_Equals_IMP(SnowballStopFilter *self, Obj *other) {
     if ((SnowballStopFilter*)other == self)   { return true; }
-    if (!Obj_Is_A(other, SNOWBALLSTOPFILTER)) { return false; }
+    if (!Obj_is_a(other, SNOWBALLSTOPFILTER)) { return false; }
     SnowballStopFilterIVARS *const ivars = SnowStop_IVARS(self);
     SnowballStopFilterIVARS *const ovars
         = SnowStop_IVARS((SnowballStopFilter*)other);
@@ -145,7 +146,7 @@ SnowStop_gen_stoplist(String *language) {
     for (uint32_t i = 0; words[i] != NULL; i++) {
         char *word = (char*)words[i];
         String *stop = Str_new_wrap_trusted_utf8(word, strlen(word));
-        Hash_Store(stoplist, (Obj*)stop, (Obj*)CFISH_TRUE);
+        Hash_Store(stoplist, stop, (Obj*)CFISH_TRUE);
         DECREF(stop);
     }
     return (Hash*)stoplist;
