@@ -20,6 +20,7 @@
 #include "Lucy/Document/HitDoc.h"
 #include "Lucy/Store/InStream.h"
 #include "Lucy/Store/OutStream.h"
+#include "Lucy/Util/Json.h"
 
 HitDoc*
 HitDoc_new(void *fields, int32_t doc_id, float score) {
@@ -82,14 +83,14 @@ HitDoc_Load_IMP(HitDoc *self, Obj *dump) {
     HitDoc *loaded = super_load(self, dump);
     HitDocIVARS *const loaded_ivars = HitDoc_IVARS(loaded);
     Obj *score = CERTIFY(Hash_Fetch_Utf8(source, "score", 5), OBJ);
-    loaded_ivars->score = (float)Obj_To_F64(score);
+    loaded_ivars->score = (float)Json_obj_to_f64(score);
     return loaded;
 }
 
 bool
 HitDoc_Equals_IMP(HitDoc *self, Obj *other) {
     if ((HitDoc*)other == self)           { return true;  }
-    if (!Obj_Is_A(other, HITDOC))         { return false; }
+    if (!Obj_is_a(other, HITDOC))         { return false; }
     HitDoc_Equals_t super_equals
         = (HitDoc_Equals_t)SUPER_METHOD_PTR(HITDOC, LUCY_HitDoc_Equals);
     if (!super_equals(self, other))       { return false; }
