@@ -20,6 +20,8 @@
 
 #include <math.h>
 
+#include "Clownfish/HashIterator.h"
+#include "Clownfish/Num.h"
 #include "Lucy/Index/DeletionsWriter.h"
 #include "Lucy/Index/DeletionsReader.h"
 #include "Lucy/Index/IndexReader.h"
@@ -37,6 +39,7 @@
 #include "Lucy/Search/Query.h"
 #include "Lucy/Store/Folder.h"
 #include "Lucy/Store/OutStream.h"
+#include "Lucy/Util/Json.h"
 
 DeletionsWriter*
 DelWriter_init(DeletionsWriter *self, Schema *schema, Snapshot *snapshot,
@@ -84,16 +87,16 @@ DefDelWriter_init(DefaultDeletionsWriter *self, Schema *schema,
     DataWriter_init((DataWriter*)self, schema, snapshot, segment, polyreader);
     DefaultDeletionsWriterIVARS *const ivars = DefDelWriter_IVARS(self);
     ivars->seg_readers          = PolyReader_Seg_Readers(polyreader);
-    uint32_t num_seg_readers    = VA_Get_Size(ivars->seg_readers);
+    uint32_t num_seg_readers    = Vec_Get_Size(ivars->seg_readers);
     ivars->seg_starts           = PolyReader_Offsets(polyreader);
-    ivars->bit_vecs             = VA_new(num_seg_readers);
+    ivars->bit_vecs             = Vec_new(num_seg_readers);
     ivars->updated              = (bool*)CALLOCATE(num_seg_readers, sizeof(bool));
     ivars->searcher             = IxSearcher_new((Obj*)polyreader);
     ivars->name_to_tick         = Hash_new(num_seg_readers);
 
     // Materialize a BitVector of deletions for each segment.
     for (uint32_t i = 0; i < num_seg_readers; i++) {
-        SegReader *seg_reader = (SegReader*)VA_Fetch(ivars->seg_readers, i);
+        SegReader *seg_reader = (SegReader*)Vec_Fetch(ivars->seg_readers, i);
         BitVector *bit_vec    = BitVec_new(SegReader_Doc_Max(seg_reader));
         DeletionsReader *del_reader
             = (DeletionsReader*)SegReader_Fetch(
@@ -109,10 +112,10 @@ DefDelWriter_init(DefaultDeletionsWriter *self, Schema *schema,
             }
             DECREF(seg_dels);
         }
-        VA_Store(ivars->bit_vecs, i, (Obj*)bit_vec);
+        Vec_Store(ivars->bit_vecs, i, (Obj*)bit_vec);
         Hash_Store(ivars->name_to_tick,
-                   (Obj*)SegReader_Get_Seg_Name(seg_reader),
-                   (Obj*)Int32_new(i));
+                   SegReader_Get_Seg_Name(seg_reader),
+                   (Obj*)Int_new(i));
     }
 
     return self;
@@ -143,10 +146,10 @@ DefDelWriter_Finish_IMP(DefaultDeletionsWriter *self) {
     DefaultDeletionsWriterIVARS *const ivars = DefDelWriter_IVARS(self);
     Folder *const folder = ivars->folder;
 
-    for (uint32_t i = 0, max = VA_Get_Size(ivars->seg_readers); i < max; i++) {
-        SegReader *seg_reader = (SegReader*)VA_Fetch(ivars->seg_readers, i);
+    for (uint32_t i = 0, max = Vec_Get_Size(ivars->seg_readers); i < max; i++) {
+        SegReader *seg_reader = (SegReader*)Vec_Fetch(ivars->seg_readers, i);
         if (ivars->updated[i]) {
-            BitVector *deldocs   = (BitVector*)VA_Fetch(ivars->bit_vecs, i);
+            BitVector *deldocs   = (BitVector*)Vec_Fetch(ivars->bit_vecs, i);
             int32_t    doc_max   = SegReader_Doc_Max(seg_reader);
             double     used      = (doc_max + 1) / 8.0;
             uint32_t   byte_size = (uint32_t)ceil(used);
@@ -181,17 +184,17 @@ DefDelWriter_Metadata_IMP(DefaultDeletionsWriter *self) {
     Hash    *const metadata = super_meta(self);
     Hash    *const files    = Hash_new(0);
 
-    for (uint32_t i = 0, max = VA_Get_Size(ivars->seg_readers); i < max; i++) {
-        SegReader *seg_reader = (SegReader*)VA_Fetch(ivars->seg_readers, i);
+    for (uint32_t i = 0, max = Vec_Get_Size(ivars->seg_readers); i < max; i++) {
+        SegReader *seg_reader = (SegReader*)Vec_Fetch(ivars->seg_readers, i);
         if (ivars->updated[i]) {
-            BitVector *deldocs   = (BitVector*)VA_Fetch(ivars->bit_vecs, i);
+            BitVector *deldocs   = (BitVector*)Vec_Fetch(ivars->bit_vecs, i);
             Segment   *segment   = SegReader_Get_Segment(seg_reader);
             Hash      *mini_meta = Hash_new(2);
             Hash_Store_Utf8(mini_meta, "count", 5,
                             (Obj*)Str_newf("%u32", (uint32_t)BitVec_Count(deldocs)));
             Hash_Store_Utf8(mini_meta, "filename", 8,
                             (Obj*)S_del_filename(self, seg_reader));
-            Hash_Store(files, (Obj*)Seg_Get_Name(segment), (Obj*)mini_meta);
+            Hash_Store(files, Seg_Get_Name(segment), (Obj*)mini_meta);
         }
     }
     Hash_Store_Utf8(metadata, "files", 5, (Obj*)files);
@@ -212,11 +215,11 @@ DefDelWriter_Seg_Deletions_IMP(DefaultDeletionsWriter *self,
     Matcher *deletions    = NULL;
     Segment *segment      = SegReader_Get_Segment(seg_reader);
     String  *seg_name     = Seg_Get_Name(segment);
-    Integer32 *tick_obj   = (Integer32*)Hash_Fetch(ivars->name_to_tick,
-                                                   (Obj*)seg_name);
-    int32_t tick          = tick_obj ? Int32_Get_Value(tick_obj) : 0;
+    Integer *tick_obj     = (Integer*)Hash_Fetch(ivars->name_to_tick,
+                                                   seg_name);
+    int32_t tick          = tick_obj ? (int32_t)Int_Get_Value(tick_obj) : 0;
     SegReader *candidate  = tick_obj
-                            ? (SegReader*)VA_Fetch(ivars->seg_readers, tick)
+                            ? (SegReader*)Vec_Fetch(ivars->seg_readers, tick)
                             : NULL;
 
     if (tick_obj) {
@@ -224,7 +227,7 @@ DefDelWriter_Seg_Deletions_IMP(DefaultDeletionsWriter *self,
             = (DeletionsReader*)SegReader_Obtain(
                   candidate, Class_Get_Name(DELETIONSREADER));
         if (ivars->updated[tick] || DelReader_Del_Count(del_reader)) {
-            BitVector *deldocs = (BitVector*)VA_Fetch(ivars->bit_vecs, tick);
+            BitVector *deldocs = (BitVector*)Vec_Fetch(ivars->bit_vecs, tick);
             deletions = (Matcher*)BitVecMatcher_new(deldocs);
         }
     }
@@ -239,10 +242,9 @@ int32_t
 DefDelWriter_Seg_Del_Count_IMP(DefaultDeletionsWriter *self,
                                String *seg_name) {
     DefaultDeletionsWriterIVARS *const ivars = DefDelWriter_IVARS(self);
-    Integer32 *tick
-        = (Integer32*)Hash_Fetch(ivars->name_to_tick, (Obj*)seg_name);
+    Integer *tick = (Integer*)Hash_Fetch(ivars->name_to_tick, seg_name);
     BitVector *deldocs = tick
-                         ? (BitVector*)VA_Fetch(ivars->bit_vecs, Int32_Get_Value(tick))
+                         ? (BitVector*)Vec_Fetch(ivars->bit_vecs, Int_Get_Value(tick))
                          : NULL;
     return deldocs ? BitVec_Count(deldocs) : 0;
 }
@@ -251,12 +253,12 @@ void
 DefDelWriter_Delete_By_Term_IMP(DefaultDeletionsWriter *self,
                                 String *field, Obj *term) {
     DefaultDeletionsWriterIVARS *const ivars = DefDelWriter_IVARS(self);
-    for (uint32_t i = 0, max = VA_Get_Size(ivars->seg_readers); i < max; i++) {
-        SegReader *seg_reader = (SegReader*)VA_Fetch(ivars->seg_readers, i);
+    for (uint32_t i = 0, max = Vec_Get_Size(ivars->seg_readers); i < max; i++) {
+        SegReader *seg_reader = (SegReader*)Vec_Fetch(ivars->seg_readers, i);
         PostingListReader *plist_reader
             = (PostingListReader*)SegReader_Fetch(
                   seg_reader, Class_Get_Name(POSTINGLISTREADER));
-        BitVector *bit_vec = (BitVector*)VA_Fetch(ivars->bit_vecs, i);
+        BitVector *bit_vec = (BitVector*)Vec_Fetch(ivars->bit_vecs, i);
         PostingList *plist = plist_reader
                              ? PListReader_Posting_List(plist_reader, field, term)
                              : NULL;
@@ -281,9 +283,9 @@ DefDelWriter_Delete_By_Query_IMP(DefaultDeletionsWriter *self, Query *query) {
     Compiler *compiler = Query_Make_Compiler(query, (Searcher*)ivars->searcher,
                                              Query_Get_Boost(query), false);
 
-    for (uint32_t i = 0, max = VA_Get_Size(ivars->seg_readers); i < max; i++) {
-        SegReader *seg_reader = (SegReader*)VA_Fetch(ivars->seg_readers, i);
-        BitVector *bit_vec = (BitVector*)VA_Fetch(ivars->bit_vecs, i);
+    for (uint32_t i = 0, max = Vec_Get_Size(ivars->seg_readers); i < max; i++) {
+        SegReader *seg_reader = (SegReader*)Vec_Fetch(ivars->seg_readers, i);
+        BitVector *bit_vec = (BitVector*)Vec_Fetch(ivars->bit_vecs, i);
         Matcher *matcher = Compiler_Make_Matcher(compiler, seg_reader, false);
 
         if (matcher) {
@@ -308,7 +310,7 @@ void
 DefDelWriter_Delete_By_Doc_ID_IMP(DefaultDeletionsWriter *self, int32_t doc_id) {
     DefaultDeletionsWriterIVARS *const ivars = DefDelWriter_IVARS(self);
     uint32_t   sub_tick   = PolyReader_sub_tick(ivars->seg_starts, doc_id);
-    BitVector *bit_vec    = (BitVector*)VA_Fetch(ivars->bit_vecs, sub_tick);
+    BitVector *bit_vec    = (BitVector*)Vec_Fetch(ivars->bit_vecs, sub_tick);
     uint32_t   offset     = I32Arr_Get(ivars->seg_starts, sub_tick);
     int32_t    seg_doc_id = doc_id - offset;
 
@@ -321,7 +323,7 @@ DefDelWriter_Delete_By_Doc_ID_IMP(DefaultDeletionsWriter *self, int32_t doc_id)
 bool
 DefDelWriter_Updated_IMP(DefaultDeletionsWriter *self) {
     DefaultDeletionsWriterIVARS *const ivars = DefDelWriter_IVARS(self);
-    for (uint32_t i = 0, max = VA_Get_Size(ivars->seg_readers); i < max; i++) {
+    for (uint32_t i = 0, max = Vec_Get_Size(ivars->seg_readers); i < max; i++) {
         if (ivars->updated[i]) { return true; }
     }
     return false;
@@ -347,21 +349,21 @@ DefDelWriter_Merge_Segment_IMP(DefaultDeletionsWriter *self,
     Hash *del_meta = (Hash*)Seg_Fetch_Metadata_Utf8(segment, "deletions", 9);
 
     if (del_meta) {
-        VArray *seg_readers = ivars->seg_readers;
+        Vector *seg_readers = ivars->seg_readers;
         Hash   *files = (Hash*)Hash_Fetch_Utf8(del_meta, "files", 5);
         if (files) {
-            String *seg;
-            Hash *mini_meta;
-            Hash_Iterate(files);
-            while (Hash_Next(files, (Obj**)&seg, (Obj**)&mini_meta)) {
+            HashIterator *iter = HashIter_new(files);
+            while (HashIter_Next(iter)) {
+                String *seg       = HashIter_Get_Key(iter);
+                Hash   *mini_meta = (Hash*)HashIter_Get_Value(iter);
 
                 /* Find the segment the deletions from the SegReader
                  * we're adding correspond to.  If it's gone, we don't
                  * need to worry about losing deletions files that point
                  * at it. */
-                for (uint32_t i = 0, max = VA_Get_Size(seg_readers); i < max; i++) {
+                for (uint32_t i = 0, max = Vec_Get_Size(seg_readers); i < max; i++) {
                     SegReader *candidate
-                        = (SegReader*)VA_Fetch(seg_readers, i);
+                        = (SegReader*)Vec_Fetch(seg_readers, i);
                     String *candidate_name
                         = Seg_Get_Name(SegReader_Get_Segment(candidate));
 
@@ -370,7 +372,7 @@ DefDelWriter_Merge_Segment_IMP(DefaultDeletionsWriter *self,
                          * merge away the most recent deletions file
                          * pointing at this target segment -- so force a
                          * new file to be written out. */
-                        int32_t count = (int32_t)Obj_To_I64(Hash_Fetch_Utf8(mini_meta, "count", 5));
+                        int32_t count = (int32_t)Json_obj_to_i64(Hash_Fetch_Utf8(mini_meta, "count", 5));
                         DeletionsReader *del_reader
                             = (DeletionsReader*)SegReader_Obtain(
                                   candidate, Class_Get_Name(DELETIONSREADER));
@@ -381,6 +383,7 @@ DefDelWriter_Merge_Segment_IMP(DefaultDeletionsWriter *self,
                     }
                 }
             }
+            DECREF(iter);
         }
     }
 }
