@@ -26,6 +26,7 @@
 #include "Lucy/Plan/Schema.h"
 #include "Lucy/Store/Folder.h"
 #include "Lucy/Store/InStream.h"
+#include "Lucy/Util/NumberUtils.h"
 
 // Read the data we've arrived at after a seek operation.
 static void
@@ -153,15 +154,15 @@ LexIndex_Seek_IMP(LexIndex *self, Obj *target) {
         return;
     }
     else {
-        if (!Obj_Is_A(target, STRING)) {
+        if (!Obj_is_a(target, STRING)) {
             THROW(ERR, "Target is a %o, and not comparable to a %o",
-                  Obj_Get_Class_Name(target), Class_Get_Name(STRING));
+                  Obj_get_class_name(target), Class_Get_Name(STRING));
         }
         /* TODO:
-        Obj *first_obj = VA_Fetch(terms, 0);
-        if (!Obj_Is_A(target, Obj_Get_Class(first_obj))) {
+        Obj *first_obj = Vec_Fetch(terms, 0);
+        if (!Obj_is_a(target, Obj_get_class(first_obj))) {
             THROW(ERR, "Target is a %o, and not comparable to a %o",
-                Obj_Get_Class_Name(target), Obj_Get_Class_Name(first_obj));
+                Obj_get_class_name(target), Obj_get_class_name(first_obj));
         }
         */
     }
