@@ -22,7 +22,7 @@
 #include "Lucy/Util/ToolSet.h"
 
 #include "Lucy/Index/PostingPool.h"
-#include "Clownfish/CharBuf.h"
+#include "Clownfish/ByteBuf.h"
 #include "Lucy/Analysis/Inversion.h"
 #include "Lucy/Plan/Architecture.h"
 #include "Lucy/Plan/FieldType.h"
@@ -144,9 +144,9 @@ PostPool_Destroy_IMP(PostingPool *self) {
 }
 
 int
-PostPool_Compare_IMP(PostingPool *self, void *va, void *vb) {
-    RawPostingIVARS *const a     = RawPost_IVARS(*(RawPosting**)va);
-    RawPostingIVARS *const b     = RawPost_IVARS(*(RawPosting**)vb);
+PostPool_Compare_IMP(PostingPool *self, Obj **ptr_a, Obj **ptr_b) {
+    RawPostingIVARS *const a     = RawPost_IVARS(*(RawPosting**)ptr_a);
+    RawPostingIVARS *const b     = RawPost_IVARS(*(RawPosting**)ptr_b);
     const size_t      a_len = a->content_len;
     const size_t      b_len = b->content_len;
     const size_t      len   = a_len < b_len ? a_len : b_len;
@@ -174,7 +174,7 @@ PostPool_Get_Mem_Pool_IMP(PostingPool *self) {
 void
 PostPool_Flip_IMP(PostingPool *self) {
     PostingPoolIVARS *const ivars = PostPool_IVARS(self);
-    uint32_t num_runs   = VA_Get_Size(ivars->runs);
+    uint32_t num_runs   = Vec_Get_Size(ivars->runs);
     uint32_t sub_thresh = num_runs > 0
                           ? ivars->mem_thresh / num_runs
                           : ivars->mem_thresh;
@@ -218,7 +218,7 @@ PostPool_Flip_IMP(PostingPool *self) {
 
     // Assign.
     for (uint32_t i = 0; i < num_runs; i++) {
-        PostingPool *run = (PostingPool*)VA_Fetch(ivars->runs, i);
+        PostingPool *run = (PostingPool*)Vec_Fetch(ivars->runs, i);
         if (run != NULL) {
             PostPool_Set_Mem_Thresh(run, sub_thresh);
             if (!PostPool_IVARS(run)->lexicon) {
@@ -353,10 +353,10 @@ S_write_terms_and_postings(PostingPool *self, PostingWriter *post_writer,
     RawPosting *posting
         = (RawPosting*)CERTIFY(PostPool_Fetch(self), RAWPOSTING);
     RawPostingIVARS *post_ivars = RawPost_IVARS(posting);
-    CharBuf *last_term_text
-        = CB_new_from_trusted_utf8(post_ivars->blob, post_ivars->content_len);
-    const char *last_text_buf  = CB_Get_Ptr8(last_term_text);
-    uint32_t    last_text_size = CB_Get_Size(last_term_text);
+    ByteBuf *last_term_text
+        = BB_new_bytes(post_ivars->blob, post_ivars->content_len);
+    char     *last_text_buf  = BB_Get_Buf(last_term_text);
+    uint32_t  last_text_size = BB_Get_Size(last_term_text);
     SkipStepper_Set_ID_And_Filepos(skip_stepper, 0, 0);
 
     // Initialize sentinel to be used on the last iter, using an empty string
@@ -402,10 +402,10 @@ S_write_terms_and_postings(PostingPool *self, PostingWriter *post_writer,
             last_skip_filepos     = tinfo_ivars->post_filepos;
 
             // Remember the term_text so we can write string diffs.
-            CB_Mimic_Utf8(last_term_text, post_ivars->blob,
-                          post_ivars->content_len);
-            last_text_buf  = CB_Get_Ptr8(last_term_text);
-            last_text_size = CB_Get_Size(last_term_text);
+            last_text_size = post_ivars->content_len;
+            last_text_buf  = BB_Grow(last_term_text, last_text_size);
+            memcpy(last_text_buf, post_ivars->blob, last_text_size);
+            BB_Set_Size(last_term_text, last_text_size);
         }
 
         // Bail on last iter before writing invalid posting data.
@@ -485,7 +485,7 @@ PostPool_Refill_IMP(PostingPool *self) {
             if (Lex_Next(lexicon)) {
                 ivars->post_count = Lex_Doc_Freq(lexicon);
                 term_text = (String*)Lex_Get_Term(lexicon);
-                if (term_text && !Obj_Is_A((Obj*)term_text, STRING)) {
+                if (term_text && !Obj_is_a((Obj*)term_text, STRING)) {
                     THROW(ERR, "Only String terms are supported for now");
                 }
                 Posting *posting = PList_Get_Posting(plist);
