@@ -22,6 +22,7 @@
 #include "Lucy/Util/ToolSet.h"
 
 #include "Lucy/Index/SortCache/NumericSortCache.h"
+#include "Clownfish/Num.h"
 #include "Lucy/Index/Segment.h"
 #include "Lucy/Plan/FieldType.h"
 #include "Lucy/Plan/NumericType.h"
@@ -35,7 +36,7 @@ NumSortCache_init(NumericSortCache *self, String *field,
                   int32_t null_ord, int32_t ord_width, InStream *ord_in,
                   InStream *dat_in) {
     // Validate.
-    if (!type || !FType_Sortable(type) || !FType_Is_A(type, NUMERICTYPE)) {
+    if (!type || !FType_Sortable(type) || !FType_is_a(type, NUMERICTYPE)) {
         DECREF(self);
         THROW(ERR, "'%o' isn't a sortable NumericType field", field);
     }
@@ -113,7 +114,7 @@ F64SortCache_Value_IMP(Float64SortCache *self, int32_t ord) {
     }
     else {
         InStream_Seek(ivars->dat_in, ord * sizeof(double));
-        return (Obj*)Float64_new(InStream_Read_F64(ivars->dat_in));
+        return (Obj*)Float_new(InStream_Read_F64(ivars->dat_in));
     }
 }
 
@@ -151,7 +152,7 @@ F32SortCache_Value_IMP(Float32SortCache *self, int32_t ord) {
     }
     else {
         InStream_Seek(ivars->dat_in, ord * sizeof(float));
-        return (Obj*)Float32_new(InStream_Read_F32(ivars->dat_in));
+        return (Obj*)Float_new(InStream_Read_F32(ivars->dat_in));
     }
 }
 
@@ -189,7 +190,7 @@ I32SortCache_Value_IMP(Int32SortCache *self, int32_t ord) {
     }
     else {
         InStream_Seek(ivars->dat_in, ord * sizeof(int32_t));
-        return (Obj*)Int32_new(InStream_Read_I32(ivars->dat_in));
+        return (Obj*)Int_new(InStream_Read_I32(ivars->dat_in));
     }
 }
 
@@ -227,7 +228,7 @@ I64SortCache_Value_IMP(Int64SortCache *self, int32_t ord) {
     }
     else {
         InStream_Seek(ivars->dat_in, ord * sizeof(int64_t));
-        return (Obj*)Int64_new(InStream_Read_I64(ivars->dat_in));
+        return (Obj*)Int_new(InStream_Read_I64(ivars->dat_in));
     }
 }
 
