@@ -95,21 +95,22 @@ Compiler_Normalize_IMP(Compiler *self) {
     Compiler_Apply_Norm_Factor(self, factor);
 }
 
-VArray*
+Vector*
 Compiler_Highlight_Spans_IMP(Compiler *self, Searcher *searcher,
                              DocVector *doc_vec, String *field) {
     UNUSED_VAR(self);
     UNUSED_VAR(searcher);
     UNUSED_VAR(doc_vec);
     UNUSED_VAR(field);
-    return VA_new(0);
+    return Vec_new(0);
 }
 
 String*
 Compiler_To_String_IMP(Compiler *self) {
     CompilerIVARS *const ivars = Compiler_IVARS(self);
     String *stringified_query = Query_To_String(ivars->parent);
-    CharBuf *buf = CB_new_from_trusted_utf8("compiler(", 9);
+    CharBuf *buf = CB_new(0);
+    CB_Cat_Trusted_Utf8(buf, "compiler(", 9);
     CB_Cat(buf, stringified_query);
     CB_Cat_Trusted_Utf8(buf, ")", 1);
     String *string = CB_Yield_String(buf);
@@ -121,7 +122,7 @@ Compiler_To_String_IMP(Compiler *self) {
 bool
 Compiler_Equals_IMP(Compiler *self, Obj *other) {
     if ((Compiler*)other == self)                          { return true; }
-    if (!Obj_Is_A(other, COMPILER))                        { return false; }
+    if (!Obj_is_a(other, COMPILER))                        { return false; }
     CompilerIVARS *const ivars = Compiler_IVARS(self);
     CompilerIVARS *const ovars = Compiler_IVARS((Compiler*)other);
     if (ivars->boost != ovars->boost)                      { return false; }
