@@ -70,11 +70,11 @@ QueryLexer_Set_Heed_Colons_IMP(QueryLexer *self, bool heed_colons) {
     QueryLexer_IVARS(self)->heed_colons = heed_colons;
 }
 
-VArray*
+Vector*
 QueryLexer_Tokenize_IMP(QueryLexer *self, String *query_string) {
     QueryLexerIVARS *const ivars = QueryLexer_IVARS(self);
 
-    VArray *elems = VA_new(0);
+    Vector *elems = Vec_new(0);
     if (!query_string) { return elems; }
 
     StringIterator *iter = Str_Top(query_string);
@@ -82,7 +82,7 @@ QueryLexer_Tokenize_IMP(QueryLexer *self, String *query_string) {
     while (StrIter_Has_Next(iter)) {
         ParserElem *elem = NULL;
 
-        if (StrIter_Skip_Next_Whitespace(iter)) {
+        if (StrIter_Skip_Whitespace(iter)) {
             // Fast-forward past whitespace.
             continue;
         }
@@ -90,7 +90,7 @@ QueryLexer_Tokenize_IMP(QueryLexer *self, String *query_string) {
         if (ivars->heed_colons) {
             ParserElem *elem = S_consume_field(iter);
             if (elem) {
-                VA_Push(elems, (Obj*)elem);
+                Vec_Push(elems, (Obj*)elem);
             }
         }
 
@@ -104,7 +104,7 @@ QueryLexer_Tokenize_IMP(QueryLexer *self, String *query_string) {
                 break;
             case '+':
                 if (StrIter_Has_Next(iter)
-                    && !StrIter_Skip_Next_Whitespace(iter)
+                    && !StrIter_Skip_Whitespace(iter)
                    ) {
                     elem = ParserElem_new(TOKEN_PLUS, NULL);
                 }
@@ -114,7 +114,7 @@ QueryLexer_Tokenize_IMP(QueryLexer *self, String *query_string) {
                 break;
             case '-':
                 if (StrIter_Has_Next(iter)
-                    && !StrIter_Skip_Next_Whitespace(iter)
+                    && !StrIter_Skip_Whitespace(iter)
                    ) {
                     elem = ParserElem_new(TOKEN_MINUS, NULL);
                 }
@@ -152,7 +152,7 @@ QueryLexer_Tokenize_IMP(QueryLexer *self, String *query_string) {
                 elem = S_consume_text(iter);
                 break;
         }
-        VA_Push(elems, (Obj*)elem);
+        Vec_Push(elems, (Obj*)elem);
     }
 
     DECREF(iter);
@@ -169,7 +169,7 @@ S_consume_keyword(StringIterator *iter, const char *keyword,
     StringIterator *temp = StrIter_Clone(iter);
     StrIter_Advance(temp, keyword_len);
     int32_t lookahead = StrIter_Next(temp);
-    if (lookahead == STRITER_DONE) {
+    if (lookahead == STR_OOB) {
         DECREF(temp);
         return NULL;
     }
@@ -195,7 +195,7 @@ S_consume_field(StringIterator *iter) {
 
     // Field names constructs must start with a letter or underscore.
     int32_t code_point = StrIter_Next(temp);
-    if (code_point == STRITER_DONE) {
+    if (code_point == STR_OOB) {
         DECREF(temp);
         return NULL;
     }
@@ -206,7 +206,7 @@ S_consume_field(StringIterator *iter) {
 
     // Only alphanumerics and underscores are allowed in field names.
     while (':' != (code_point = StrIter_Next(temp))) {
-        if (code_point == STRITER_DONE) {
+        if (code_point == STR_OOB) {
             DECREF(temp);
             return NULL;
         }
@@ -218,7 +218,7 @@ S_consume_field(StringIterator *iter) {
 
     // Field name constructs must be followed by something sensible.
     int32_t lookahead = StrIter_Next(temp);
-    if (lookahead == STRITER_DONE) {
+    if (lookahead == STR_OOB) {
         DECREF(temp);
         return NULL;
     }
@@ -235,7 +235,7 @@ S_consume_field(StringIterator *iter) {
 
     // Consume string data.
     StrIter_Recede(temp, 2); // Back up over lookahead and colon.
-    String *field = StrIter_substring(iter, temp);
+    String *field = StrIter_crop(iter, temp);
     StrIter_Advance(temp, 1); // Skip colon.
     StrIter_Assign(iter, temp);
     DECREF(temp);
@@ -250,11 +250,11 @@ S_consume_text(StringIterator *iter) {
         int32_t code_point = StrIter_Next(temp);
         if (code_point == '\\') {
             code_point = StrIter_Next(temp);
-            if (code_point == STRITER_DONE) {
+            if (code_point == STR_OOB) {
                 break;
             }
         }
-        else if (code_point == STRITER_DONE) {
+        else if (code_point == STR_OOB) {
             break;
         }
         else if (StrHelp_is_whitespace(code_point)
@@ -267,7 +267,7 @@ S_consume_text(StringIterator *iter) {
         }
     }
 
-    String *text = StrIter_substring(iter, temp);
+    String *text = StrIter_crop(iter, temp);
     StrIter_Assign(iter, temp);
     DECREF(temp);
     return ParserElem_new(TOKEN_STRING, (Obj*)text);
@@ -283,7 +283,7 @@ S_consume_quoted_string(StringIterator *iter) {
 
     while (1) {
         int32_t code_point = StrIter_Next(temp);
-        if (code_point == STRITER_DONE || code_point == '"') {
+        if (code_point == STR_OOB || code_point == '"') {
             break;
         }
         else if (code_point == '\\') {
@@ -291,7 +291,7 @@ S_consume_quoted_string(StringIterator *iter) {
         }
     }
 
-    String *text = StrIter_substring(iter, temp);
+    String *text = StrIter_crop(iter, temp);
     StrIter_Assign(iter, temp);
     DECREF(temp);
     return ParserElem_new(TOKEN_STRING, (Obj*)text);
