@@ -112,7 +112,7 @@ TermQuery_Get_Term_IMP(TermQuery *self) {
 bool
 TermQuery_Equals_IMP(TermQuery *self, Obj *other) {
     if ((TermQuery*)other == self)                     { return true; }
-    if (!Obj_Is_A(other, TERMQUERY))                   { return false; }
+    if (!Obj_is_a(other, TERMQUERY))                   { return false; }
     TermQueryIVARS *const ivars = TermQuery_IVARS(self);
     TermQueryIVARS *const ovars = TermQuery_IVARS((TermQuery*)other);
     if (ivars->boost != ovars->boost)                  { return false; }
@@ -193,7 +193,7 @@ TermCompiler_Equals_IMP(TermCompiler *self, Obj *other) {
         = (TermCompiler_Equals_t)SUPER_METHOD_PTR(TERMCOMPILER,
                                                   LUCY_TermCompiler_Equals);
     if (!super_equals(self, other))                           { return false; }
-    if (!Obj_Is_A(other, TERMCOMPILER))                       { return false; }
+    if (!Obj_is_a(other, TERMCOMPILER))                       { return false; }
     TermCompilerIVARS *const ivars = TermCompiler_IVARS(self);
     TermCompilerIVARS *const ovars = TermCompiler_IVARS((TermCompiler*)other);
     if (ivars->idf != ovars->idf)                             { return false; }
@@ -282,14 +282,14 @@ TermCompiler_Make_Matcher_IMP(TermCompiler *self, SegReader *reader,
     }
 }
 
-VArray*
+Vector*
 TermCompiler_Highlight_Spans_IMP(TermCompiler *self, Searcher *searcher,
                                  DocVector *doc_vec, String *field) {
 
     TermCompilerIVARS *const ivars = TermCompiler_IVARS(self);
     TermQueryIVARS *const parent_ivars
         = TermQuery_IVARS((TermQuery*)ivars->parent);
-    VArray *spans = VA_new(0);
+    Vector *spans = Vec_new(0);
     TermVector *term_vector;
     I32Array *starts, *ends;
     UNUSED_VAR(searcher);
@@ -306,7 +306,7 @@ TermCompiler_Highlight_Spans_IMP(TermCompiler *self, Searcher *searcher,
     for (uint32_t i = 0, max = I32Arr_Get_Size(starts); i < max; i++) {
         int32_t start  = I32Arr_Get(starts, i);
         int32_t length = I32Arr_Get(ends, i) - start;
-        VA_Push(spans,
+        Vec_Push(spans,
                 (Obj*)Span_new(start, length, TermCompiler_Get_Weight(self)));
     }
 
