@@ -56,15 +56,14 @@ RAMFolder_Check_IMP(RAMFolder *self) {
 bool
 RAMFolder_Local_MkDir_IMP(RAMFolder *self, String *name) {
     RAMFolderIVARS *const ivars = RAMFolder_IVARS(self);
-    if (Hash_Fetch(ivars->entries, (Obj*)name)) {
+    if (Hash_Fetch(ivars->entries, name)) {
         Err_set_error(Err_new(Str_newf("Can't MkDir, '%o' already exists",
                                        name)));
         return false;
     }
     else {
         String *fullpath = S_fullpath(self, name);
-        Hash_Store(ivars->entries, (Obj*)name,
-                   (Obj*)RAMFolder_new(fullpath));
+        Hash_Store(ivars->entries, name, (Obj*)RAMFolder_new(fullpath));
         DECREF(fullpath);
         return true;
     }
@@ -76,7 +75,7 @@ RAMFolder_Local_Open_FileHandle_IMP(RAMFolder *self, String *name,
     RAMFolderIVARS *const ivars = RAMFolder_IVARS(self);
     RAMFileHandle *fh;
     String *fullpath = S_fullpath(self, name);
-    RAMFile *file = (RAMFile*)Hash_Fetch(ivars->entries, (Obj*)name);
+    RAMFile *file = (RAMFile*)Hash_Fetch(ivars->entries, name);
     bool can_create
         = (flags & (FH_WRITE_ONLY | FH_CREATE)) == (FH_WRITE_ONLY | FH_CREATE)
           ? true : false;
@@ -84,7 +83,7 @@ RAMFolder_Local_Open_FileHandle_IMP(RAMFolder *self, String *name,
     // Make sure the filepath isn't a directory, and that it either exists
     // or we have permission to create it.
     if (file) {
-        if (!RAMFile_Is_A(file, RAMFILE)) {
+        if (!RAMFile_is_a(file, RAMFILE)) {
             Err_set_error(Err_new(Str_newf("Not a file: '%o'", fullpath)));
             DECREF(fullpath);
             return NULL;
@@ -101,7 +100,7 @@ RAMFolder_Local_Open_FileHandle_IMP(RAMFolder *self, String *name,
     if (fh) {
         if (!file) {
             file = RAMFH_Get_File(fh);
-            Hash_Store(ivars->entries, (Obj*)name, INCREF(file));
+            Hash_Store(ivars->entries, name, INCREF(file));
         }
     }
     else {
@@ -124,14 +123,14 @@ RAMFolder_Local_Open_Dir_IMP(RAMFolder *self) {
 bool
 RAMFolder_Local_Exists_IMP(RAMFolder *self, String *name) {
     RAMFolderIVARS *const ivars = RAMFolder_IVARS(self);
-    return !!Hash_Fetch(ivars->entries, (Obj*)name);
+    return !!Hash_Fetch(ivars->entries, name);
 }
 
 bool
 RAMFolder_Local_Is_Directory_IMP(RAMFolder *self, String *name) {
     RAMFolderIVARS *const ivars = RAMFolder_IVARS(self);
-    Obj *entry = Hash_Fetch(ivars->entries, (Obj*)name);
-    if (entry && Obj_Is_A(entry, FOLDER)) { return true; }
+    Obj *entry = Hash_Fetch(ivars->entries, name);
+    if (entry && Obj_is_a(entry, FOLDER)) { return true; }
     return false;
 }
 
@@ -160,36 +159,35 @@ S_rename_or_hard_link(RAMFolder *self, String* from, String *to,
     }
 
     // Extract RAMFolders from compound reader wrappers, if necessary.
-    if (Folder_Is_A(from_folder, COMPOUNDFILEREADER)) {
+    if (Folder_is_a(from_folder, COMPOUNDFILEREADER)) {
         inner_from_folder = (RAMFolder*)CFReader_Get_Real_Folder(
                                 (CompoundFileReader*)from_folder);
     }
     else {
         inner_from_folder = (RAMFolder*)from_folder;
     }
-    if (Folder_Is_A(to_folder, COMPOUNDFILEREADER)) {
+    if (Folder_is_a(to_folder, COMPOUNDFILEREADER)) {
         inner_to_folder = (RAMFolder*)CFReader_Get_Real_Folder(
                               (CompoundFileReader*)to_folder);
     }
     else {
         inner_to_folder = (RAMFolder*)to_folder;
     }
-    if (!RAMFolder_Is_A(inner_from_folder, RAMFOLDER)) {
+    if (!RAMFolder_is_a(inner_from_folder, RAMFOLDER)) {
         Err_set_error(Err_new(Str_newf("Not a RAMFolder, but a '%o'",
-                                       Obj_Get_Class_Name((Obj*)inner_from_folder))));
+                                       Obj_get_class_name((Obj*)inner_from_folder))));
         return false;
     }
-    if (!RAMFolder_Is_A(inner_to_folder, RAMFOLDER)) {
+    if (!RAMFolder_is_a(inner_to_folder, RAMFOLDER)) {
         Err_set_error(Err_new(Str_newf("Not a RAMFolder, but a '%o'",
-                                       Obj_Get_Class_Name((Obj*)inner_to_folder))));
+                                       Obj_get_class_name((Obj*)inner_to_folder))));
         return false;
     }
 
     // Find the original element.
-    elem = Hash_Fetch(RAMFolder_IVARS(inner_from_folder)->entries,
-                      (Obj*)from_name);
+    elem = Hash_Fetch(RAMFolder_IVARS(inner_from_folder)->entries, from_name);
     if (!elem) {
-        if (Folder_Is_A(from_folder, COMPOUNDFILEREADER)
+        if (Folder_is_a(from_folder, COMPOUNDFILEREADER)
             && Folder_Local_Exists(from_folder, from_name)
            ) {
             Err_set_error(Err_new(Str_newf("Source file '%o' is virtual",
@@ -204,7 +202,7 @@ S_rename_or_hard_link(RAMFolder *self, String* from, String *to,
     // Execute the rename/hard-link.
     if (op == OP_RENAME) {
         Obj *existing = Hash_Fetch(RAMFolder_IVARS(inner_to_folder)->entries,
-                                   (Obj*)to_name);
+                                   to_name);
         if (existing) {
             bool conflict = false;
 
@@ -216,20 +214,20 @@ S_rename_or_hard_link(RAMFolder *self, String* from, String *to,
             }
 
             // Don't allow clobbering of different entry type.
-            if (Obj_Is_A(elem, RAMFILE)) {
-                if (!Obj_Is_A(existing, RAMFILE)) {
+            if (Obj_is_a(elem, RAMFILE)) {
+                if (!Obj_is_a(existing, RAMFILE)) {
                     conflict = true;
                 }
             }
-            else if (Obj_Is_A(elem, FOLDER)) {
-                if (!Obj_Is_A(existing, FOLDER)) {
+            else if (Obj_is_a(elem, FOLDER)) {
+                if (!Obj_is_a(existing, FOLDER)) {
                     conflict = true;
                 }
             }
             if (conflict) {
                 Err_set_error(Err_new(Str_newf("Can't clobber a %o with a %o",
-                                               Obj_Get_Class_Name(existing),
-                                               Obj_Get_Class_Name(elem))));
+                                               Obj_get_class_name(existing),
+                                               Obj_get_class_name(elem))));
                 return false;
             }
         }
@@ -237,32 +235,32 @@ S_rename_or_hard_link(RAMFolder *self, String* from, String *to,
         // Perform the store first, then the delete. Inform Folder objects
         // about the relocation.
         Hash_Store(RAMFolder_IVARS(inner_to_folder)->entries,
-                   (Obj*)to_name, INCREF(elem));
+                   to_name, INCREF(elem));
         DECREF(Hash_Delete(RAMFolder_IVARS(inner_from_folder)->entries,
-                           (Obj*)from_name));
-        if (Obj_Is_A(elem, FOLDER)) {
+                           from_name));
+        if (Obj_is_a(elem, FOLDER)) {
             String *newpath = S_fullpath(inner_to_folder, to_name);
             Folder_Set_Path((Folder*)elem, newpath);
             DECREF(newpath);
         }
     }
     else if (op == OP_HARD_LINK) {
-        if (!Obj_Is_A(elem, RAMFILE)) {
+        if (!Obj_is_a(elem, RAMFILE)) {
             Err_set_error(Err_new(Str_newf("'%o' isn't a file, it's a %o",
-                                           from, Obj_Get_Class_Name(elem))));
+                                           from, Obj_get_class_name(elem))));
             return false;
         }
         else {
             Obj *existing
                 = Hash_Fetch(RAMFolder_IVARS(inner_to_folder)->entries,
-                             (Obj*)to_name);
+                             to_name);
             if (existing) {
                 Err_set_error(Err_new(Str_newf("'%o' already exists", to)));
                 return false;
             }
             else {
                 Hash_Store(RAMFolder_IVARS(inner_to_folder)->entries,
-                           (Obj*)to_name, INCREF(elem));
+                           to_name, INCREF(elem));
             }
         }
     }
@@ -306,14 +304,14 @@ RAMFolder_Hard_Link_IMP(RAMFolder *self, String *from,
 bool
 RAMFolder_Local_Delete_IMP(RAMFolder *self, String *name) {
     RAMFolderIVARS *const ivars = RAMFolder_IVARS(self);
-    Obj *entry = Hash_Fetch(ivars->entries, (Obj*)name);
+    Obj *entry = Hash_Fetch(ivars->entries, name);
     if (entry) {
-        if (Obj_Is_A(entry, RAMFILE)) {
+        if (Obj_is_a(entry, RAMFILE)) {
             ;
         }
-        else if (Obj_Is_A(entry, FOLDER)) {
+        else if (Obj_is_a(entry, FOLDER)) {
             RAMFolder *inner_folder;
-            if (Obj_Is_A(entry, COMPOUNDFILEREADER)) {
+            if (Obj_is_a(entry, COMPOUNDFILEREADER)) {
                 inner_folder = (RAMFolder*)CERTIFY(
                                    CFReader_Get_Real_Folder((CompoundFileReader*)entry),
                                    RAMFOLDER);
@@ -329,7 +327,7 @@ RAMFolder_Local_Delete_IMP(RAMFolder *self, String *name) {
         else {
             return false;
         }
-        DECREF(Hash_Delete(ivars->entries, (Obj*)name));
+        DECREF(Hash_Delete(ivars->entries, name));
         return true;
     }
     else {
@@ -340,8 +338,8 @@ RAMFolder_Local_Delete_IMP(RAMFolder *self, String *name) {
 Folder*
 RAMFolder_Local_Find_Folder_IMP(RAMFolder *self, String *path) {
     RAMFolderIVARS *const ivars = RAMFolder_IVARS(self);
-    Folder *local_folder = (Folder*)Hash_Fetch(ivars->entries, (Obj*)path);
-    if (local_folder && Folder_Is_A(local_folder, FOLDER)) {
+    Folder *local_folder = (Folder*)Hash_Fetch(ivars->entries, path);
+    if (local_folder && Folder_is_a(local_folder, FOLDER)) {
         return local_folder;
     }
     return NULL;
