@@ -18,6 +18,7 @@
 #define TESTLUCY_USE_SHORT_NAMES
 #include "Lucy/Util/ToolSet.h"
 
+#include "Clownfish/HashIterator.h"
 #include "Clownfish/TestHarness/TestBatchRunner.h"
 #include "Lucy/Test.h"
 #include "Lucy/Test/Analysis/TestSnowballStemmer.h"
@@ -33,8 +34,8 @@ TestSnowStemmer_new() {
 
 static void
 test_Dump_Load_and_Equals(TestBatchRunner *runner) {
-    String *EN = (String*)SSTR_WRAP_UTF8("en", 2);
-    String *ES = (String*)SSTR_WRAP_UTF8("es", 2);
+    String *EN = SSTR_WRAP_C("en");
+    String *ES = SSTR_WRAP_C("es");
     SnowballStemmer *stemmer = SnowStemmer_new(EN);
     SnowballStemmer *other   = SnowStemmer_new(ES);
     Obj *dump       = (Obj*)SnowStemmer_Dump(stemmer);
@@ -63,31 +64,37 @@ test_Dump_Load_and_Equals(TestBatchRunner *runner) {
 static void
 test_stemming(TestBatchRunner *runner) {
     FSFolder *modules_folder = TestUtils_modules_folder();
+    if (modules_folder == NULL) {
+        SKIP(runner, 150, "Can't locate test data");
+        return;
+    }
+
     String *path = Str_newf("analysis/snowstem/source/test/tests.json");
     Hash *tests = (Hash*)Json_slurp_json((Folder*)modules_folder, path);
     if (!tests) { RETHROW(Err_get_error()); }
 
-    String *iso;
-    Hash *lang_data;
-    Hash_Iterate(tests);
-    while (Hash_Next(tests, (Obj**)&iso, (Obj**)&lang_data)) {
-        VArray *words = (VArray*)Hash_Fetch_Utf8(lang_data, "words", 5);
-        VArray *stems = (VArray*)Hash_Fetch_Utf8(lang_data, "stems", 5);
+    HashIterator *iter = HashIter_new(tests);
+    while (HashIter_Next(iter)) {
+        String *iso       = HashIter_Get_Key(iter);
+        Hash   *lang_data = (Hash*)HashIter_Get_Value(iter);
+        Vector *words = (Vector*)Hash_Fetch_Utf8(lang_data, "words", 5);
+        Vector *stems = (Vector*)Hash_Fetch_Utf8(lang_data, "stems", 5);
         SnowballStemmer *stemmer = SnowStemmer_new(iso);
-        for (uint32_t i = 0, max = VA_Get_Size(words); i < max; i++) {
-            String *word  = (String*)VA_Fetch(words, i);
-            VArray *got   = SnowStemmer_Split(stemmer, word);
-            String *stem  = (String*)VA_Fetch(got, 0);
+        for (uint32_t i = 0, max = Vec_Get_Size(words); i < max; i++) {
+            String *word  = (String*)Vec_Fetch(words, i);
+            Vector *got   = SnowStemmer_Split(stemmer, word);
+            String *stem  = (String*)Vec_Fetch(got, 0);
             TEST_TRUE(runner,
                       stem
-                      && Str_Is_A(stem, STRING)
-                      && Str_Equals(stem, VA_Fetch(stems, i)),
+                      && Str_is_a(stem, STRING)
+                      && Str_Equals(stem, Vec_Fetch(stems, i)),
                       "Stem %s: %s", Str_Get_Ptr8(iso), Str_Get_Ptr8(word)
                      );
             DECREF(got);
         }
         DECREF(stemmer);
     }
+    DECREF(iter);
 
     DECREF(tests);
     DECREF(modules_folder);
