@@ -51,7 +51,7 @@ static void
 test_tokenizer(TestBatchRunner *runner) {
     StandardTokenizer *tokenizer = StandardTokenizer_new();
 
-    StackString *word = SSTR_WRAP_UTF8(
+    String *word = SSTR_WRAP_C(
                               " ."
                               "tha\xCC\x82t's"
                               ":"
@@ -59,58 +59,62 @@ test_tokenizer(TestBatchRunner *runner) {
                               "\xE0\xB8\x81\xC2\xAD\xC2\xAD"
                               "\xF0\xA0\x80\x80"
                               "a"
-                              "/",
-                              35);
-    VArray *got = StandardTokenizer_Split(tokenizer, (String*)word);
-    String *token = (String*)VA_Fetch(got, 0);
+                              "/");
+    Vector *got = StandardTokenizer_Split(tokenizer, word);
+    String *token = (String*)Vec_Fetch(got, 0);
     TEST_TRUE(runner,
               token
-              && Str_Is_A(token, STRING)
+              && Str_is_a(token, STRING)
               && Str_Equals_Utf8(token, "tha\xcc\x82t's", 8),
               "Token: %s", Str_Get_Ptr8(token));
-    token = (String*)VA_Fetch(got, 1);
+    token = (String*)Vec_Fetch(got, 1);
     TEST_TRUE(runner,
               token
-              && Str_Is_A(token, STRING)
+              && Str_is_a(token, STRING)
               && Str_Equals_Utf8(token, "1,02\xC2\xADZ4.38", 11),
               "Token: %s", Str_Get_Ptr8(token));
-    token = (String*)VA_Fetch(got, 2);
+    token = (String*)Vec_Fetch(got, 2);
     TEST_TRUE(runner,
               token
-              && Str_Is_A(token, STRING)
+              && Str_is_a(token, STRING)
               && Str_Equals_Utf8(token, "\xE0\xB8\x81\xC2\xAD\xC2\xAD", 7),
               "Token: %s", Str_Get_Ptr8(token));
-    token = (String*)VA_Fetch(got, 3);
+    token = (String*)Vec_Fetch(got, 3);
     TEST_TRUE(runner,
               token
-              && Str_Is_A(token, STRING)
+              && Str_is_a(token, STRING)
               && Str_Equals_Utf8(token, "\xF0\xA0\x80\x80", 4),
               "Token: %s", Str_Get_Ptr8(token));
-    token = (String*)VA_Fetch(got, 4);
+    token = (String*)Vec_Fetch(got, 4);
     TEST_TRUE(runner,
               token
-              && Str_Is_A(token, STRING)
+              && Str_is_a(token, STRING)
               && Str_Equals_Utf8(token, "a", 1),
               "Token: %s", Str_Get_Ptr8(token));
     DECREF(got);
 
     FSFolder *modules_folder = TestUtils_modules_folder();
-    String *path = Str_newf("unicode/ucd/WordBreakTest.json");
-    VArray *tests = (VArray*)Json_slurp_json((Folder*)modules_folder, path);
-    if (!tests) { RETHROW(Err_get_error()); }
-
-    for (uint32_t i = 0, max = VA_Get_Size(tests); i < max; i++) {
-        Hash *test = (Hash*)VA_Fetch(tests, i);
-        String *text = (String*)Hash_Fetch_Utf8(test, "text", 4);
-        VArray *wanted = (VArray*)Hash_Fetch_Utf8(test, "words", 5);
-        VArray *got = StandardTokenizer_Split(tokenizer, text);
-        TEST_TRUE(runner, VA_Equals(wanted, (Obj*)got), "UCD test #%d", i + 1);
-        DECREF(got);
+    if (modules_folder == NULL) {
+        SKIP(runner, 1372, "Can't locate test data");
     }
+    else {
+        String *path = Str_newf("unicode/ucd/WordBreakTest.json");
+        Vector *tests = (Vector*)Json_slurp_json((Folder*)modules_folder, path);
+        if (!tests) { RETHROW(Err_get_error()); }
 
-    DECREF(tests);
-    DECREF(modules_folder);
-    DECREF(path);
+        for (uint32_t i = 0, max = Vec_Get_Size(tests); i < max; i++) {
+            Hash *test = (Hash*)Vec_Fetch(tests, i);
+            String *text = (String*)Hash_Fetch_Utf8(test, "text", 4);
+            Vector *wanted = (Vector*)Hash_Fetch_Utf8(test, "words", 5);
+            Vector *got = StandardTokenizer_Split(tokenizer, text);
+            TEST_TRUE(runner, Vec_Equals(wanted, (Obj*)got), "UCD test #%d", i + 1);
+            DECREF(got);
+        }
+
+        DECREF(tests);
+        DECREF(modules_folder);
+        DECREF(path);
+    }
 
     DECREF(tokenizer);
 }
