@@ -59,14 +59,14 @@ TestHighlighter_new() {
 
 static void
 test_Raw_Excerpt(TestBatchRunner *runner, Searcher *searcher, Obj *query) {
-    String *content = (String*)SSTR_WRAP_UTF8("content", 7);
+    String *content = SSTR_WRAP_C("content");
     Highlighter *highlighter = Highlighter_new(searcher, query, content, 6);
     int32_t top;
     String *raw_excerpt;
 
-    String *field_val = (String *)SSTR_WRAP_UTF8("Ook.  Urk.  Ick.  ", 18);
-    VArray *spans = VA_new(1);
-    VA_Push(spans, (Obj*)Span_new(0, 18, 1.0f));
+    String *field_val = SSTR_WRAP_C("Ook.  Urk.  Ick.  ");
+    Vector *spans = Vec_new(1);
+    Vec_Push(spans, (Obj*)Span_new(0, 18, 1.0f));
     HeatMap *heat_map = HeatMap_new(spans, 133);
     DECREF(spans);
     raw_excerpt = Highlighter_Raw_Excerpt(highlighter, field_val, &top,
@@ -80,8 +80,8 @@ test_Raw_Excerpt(TestBatchRunner *runner, Searcher *searcher, Obj *query) {
     DECREF(raw_excerpt);
     DECREF(heat_map);
 
-    spans = VA_new(1);
-    VA_Push(spans, (Obj*)Span_new(6, 12, 1.0f));
+    spans = Vec_new(1);
+    Vec_Push(spans, (Obj*)Span_new(6, 12, 1.0f));
     heat_map = HeatMap_new(spans, 133);
     DECREF(spans);
     raw_excerpt = Highlighter_Raw_Excerpt(highlighter, field_val, &top,
@@ -95,9 +95,9 @@ test_Raw_Excerpt(TestBatchRunner *runner, Searcher *searcher, Obj *query) {
     DECREF(raw_excerpt);
     DECREF(heat_map);
 
-    field_val = (String *)SSTR_WRAP_UTF8("Ook urk ick i.", 14);
-    spans     = VA_new(1);
-    VA_Push(spans, (Obj*)Span_new(12, 1, 1.0f));
+    field_val = SSTR_WRAP_C("Ook urk ick i.");
+    spans     = Vec_new(1);
+    Vec_Push(spans, (Obj*)Span_new(12, 1, 1.0f));
     heat_map = HeatMap_new(spans, 133);
     DECREF(spans);
     raw_excerpt = Highlighter_Raw_Excerpt(highlighter, field_val, &top,
@@ -111,9 +111,9 @@ test_Raw_Excerpt(TestBatchRunner *runner, Searcher *searcher, Obj *query) {
     DECREF(heat_map);
     DECREF(raw_excerpt);
 
-    field_val = (String *)SSTR_WRAP_UTF8("Urk.  Iz no good.", 17);
-    spans     = VA_new(1);
-    VA_Push(spans, (Obj*)Span_new(6, 2, 1.0f));
+    field_val = SSTR_WRAP_C("Urk.  Iz no good.");
+    spans     = Vec_new(1);
+    Vec_Push(spans, (Obj*)Span_new(6, 2, 1.0f));
     heat_map = HeatMap_new(spans, 133);
     DECREF(spans);
     raw_excerpt = Highlighter_Raw_Excerpt(highlighter, field_val, &top,
@@ -129,10 +129,10 @@ test_Raw_Excerpt(TestBatchRunner *runner, Searcher *searcher, Obj *query) {
 
     // Words longer than excerpt len
 
-    field_val = (String *)SSTR_WRAP_UTF8("abc/def/ghi/jkl/mno", 19);
+    field_val = SSTR_WRAP_C("abc/def/ghi/jkl/mno");
 
-    spans = VA_new(1);
-    VA_Push(spans, (Obj*)Span_new(0, 3, 1.0f));
+    spans = Vec_new(1);
+    Vec_Push(spans, (Obj*)Span_new(0, 3, 1.0f));
     heat_map = HeatMap_new(spans, 133);
     DECREF(spans);
     raw_excerpt = Highlighter_Raw_Excerpt(highlighter, field_val, &top,
@@ -143,8 +143,8 @@ test_Raw_Excerpt(TestBatchRunner *runner, Searcher *searcher, Obj *query) {
     DECREF(heat_map);
     DECREF(raw_excerpt);
 
-    spans = VA_new(1);
-    VA_Push(spans, (Obj*)Span_new(8, 3, 1.0f));
+    spans = Vec_new(1);
+    Vec_Push(spans, (Obj*)Span_new(8, 3, 1.0f));
     heat_map = HeatMap_new(spans, 133);
     DECREF(spans);
     raw_excerpt = Highlighter_Raw_Excerpt(highlighter, field_val, &top,
@@ -160,13 +160,13 @@ test_Raw_Excerpt(TestBatchRunner *runner, Searcher *searcher, Obj *query) {
 
 static void
 test_Highlight_Excerpt(TestBatchRunner *runner, Searcher *searcher, Obj *query) {
-    String *content = (String*)SSTR_WRAP_UTF8("content", 7);
+    String *content = SSTR_WRAP_C("content");
     Highlighter *highlighter = Highlighter_new(searcher, query, content, 3);
     String *highlighted;
 
-    VArray *spans = VA_new(1);
-    VA_Push(spans, (Obj*)Span_new(2, 1, 0.0f));
-    String *raw_excerpt = (String *)SSTR_WRAP_UTF8("a b c", 5);
+    Vector *spans = Vec_new(1);
+    Vec_Push(spans, (Obj*)Span_new(2, 1, 0.0f));
+    String *raw_excerpt = SSTR_WRAP_C("a b c");
     highlighted = Highlighter_Highlight_Excerpt(highlighter, spans,
                                                 raw_excerpt, 0);
     TEST_TRUE(runner,
@@ -175,10 +175,10 @@ test_Highlight_Excerpt(TestBatchRunner *runner, Searcher *searcher, Obj *query)
     DECREF(highlighted);
     DECREF(spans);
 
-    spans = VA_new(2);
-    VA_Push(spans, (Obj*)Span_new(0, 1, 1.0f));
-    VA_Push(spans, (Obj*)Span_new(10, 10, 1.0f));
-    raw_excerpt = (String *)SSTR_WRAP_UTF8(PHI, 2);
+    spans = Vec_new(2);
+    Vec_Push(spans, (Obj*)Span_new(0, 1, 1.0f));
+    Vec_Push(spans, (Obj*)Span_new(10, 10, 1.0f));
+    raw_excerpt = SSTR_WRAP_C(PHI);
     highlighted = Highlighter_Highlight_Excerpt(highlighter, spans,
                                                 raw_excerpt, 0);
     TEST_TRUE(runner,
@@ -187,9 +187,9 @@ test_Highlight_Excerpt(TestBatchRunner *runner, Searcher *searcher, Obj *query)
     DECREF(highlighted);
     DECREF(spans);
 
-    spans = VA_new(1);
-    VA_Push(spans, (Obj*)Span_new(3, 1, 1.0f));
-    raw_excerpt = (String *)SSTR_WRAP_UTF8(PHI " " PHI " " PHI, 8);
+    spans = Vec_new(1);
+    Vec_Push(spans, (Obj*)Span_new(3, 1, 1.0f));
+    raw_excerpt = SSTR_WRAP_C(PHI " " PHI " " PHI);
     highlighted = Highlighter_Highlight_Excerpt(highlighter, spans,
                                                 raw_excerpt, 1);
     TEST_TRUE(runner,
@@ -199,12 +199,12 @@ test_Highlight_Excerpt(TestBatchRunner *runner, Searcher *searcher, Obj *query)
     DECREF(highlighted);
     DECREF(spans);
 
-    spans = VA_new(4);
-    VA_Push(spans, (Obj*)Span_new(2, 10, 1.0f));
-    VA_Push(spans, (Obj*)Span_new(2,  4, 1.0f));
-    VA_Push(spans, (Obj*)Span_new(8,  9, 1.0f));
-    VA_Push(spans, (Obj*)Span_new(8,  4, 1.0f));
-    raw_excerpt = (String *)SSTR_WRAP_UTF8(PHI " Oook. Urk. Ick. " PHI, 21);
+    spans = Vec_new(4);
+    Vec_Push(spans, (Obj*)Span_new(2, 10, 1.0f));
+    Vec_Push(spans, (Obj*)Span_new(2,  4, 1.0f));
+    Vec_Push(spans, (Obj*)Span_new(8,  9, 1.0f));
+    Vec_Push(spans, (Obj*)Span_new(8,  4, 1.0f));
+    raw_excerpt = SSTR_WRAP_C(PHI " Oook. Urk. Ick. " PHI);
     highlighted = Highlighter_Highlight_Excerpt(highlighter, spans,
                                                 raw_excerpt, 0);
     TEST_TRUE(runner,
@@ -221,27 +221,27 @@ test_Highlight_Excerpt(TestBatchRunner *runner, Searcher *searcher, Obj *query)
 static void
 test_Create_Excerpt(TestBatchRunner *runner, Searcher *searcher, Obj *query,
                     Hits *hits) {
-    String *content = (String*)SSTR_WRAP_UTF8("content", 7);
+    String *content = SSTR_WRAP_C("content");
     Highlighter *highlighter = Highlighter_new(searcher, query, content, 200);
 
     HitDoc *hit = Hits_Next(hits);
     String *excerpt = Highlighter_Create_Excerpt(highlighter, hit);
     TEST_TRUE(runner,
-              Str_Find_Utf8(excerpt,
-                           "<strong>&#934;</strong> a b c d <strong>x y z</strong>",
-                           54) >= 0,
+              Str_Contains_Utf8(excerpt,
+                                "<strong>&#934;</strong> a b c d <strong>x y z</strong>",
+                                54),
               "highlighter tagged phrase and single term");
     DECREF(excerpt);
 
-    String *pre_tag = (String*)SSTR_WRAP_UTF8("\x1B[1m", 4);
+    String *pre_tag = SSTR_WRAP_C("\x1B[1m");
     Highlighter_Set_Pre_Tag(highlighter, pre_tag);
-    String *post_tag = (String*)SSTR_WRAP_UTF8("\x1B[0m", 4);
+    String *post_tag = SSTR_WRAP_C("\x1B[0m");
     Highlighter_Set_Post_Tag(highlighter, post_tag);
     excerpt = Highlighter_Create_Excerpt(highlighter, hit);
     TEST_TRUE(runner,
-              Str_Find_Utf8(excerpt,
-                          "\x1B[1m&#934;\x1B[0m a b c d \x1B[1mx y z\x1B[0m",
-                          36) >= 0,
+              Str_Contains_Utf8(excerpt,
+                                "\x1B[1m&#934;\x1B[0m a b c d \x1B[1mx y z\x1B[0m",
+                                36),
               "set_pre_tag and set_post_tag");
     DECREF(excerpt);
     DECREF(hit);
@@ -249,70 +249,70 @@ test_Create_Excerpt(TestBatchRunner *runner, Searcher *searcher, Obj *query,
     hit = Hits_Next(hits);
     excerpt = Highlighter_Create_Excerpt(highlighter, hit);
     TEST_TRUE(runner,
-              Str_Find_Utf8(excerpt, "x", 1) >= 0,
+              Str_Contains_Utf8(excerpt, "x", 1),
               "excerpt field with partial hit doesn't cause highlighter freakout");
     DECREF(excerpt);
     DECREF(hit);
     DECREF(highlighter);
 
-    query = (Obj*)SSTR_WRAP_UTF8("x \"x y z\" AND b", 15);
+    query = (Obj*)SSTR_WRAP_C("x \"x y z\" AND b");
     hits = Searcher_Hits(searcher, query, 0, 10, NULL);
     highlighter = Highlighter_new(searcher, query, content, 200);
     hit = Hits_Next(hits);
     excerpt = Highlighter_Create_Excerpt(highlighter, hit);
     TEST_TRUE(runner,
-              Str_Find_Utf8(excerpt,
-                          "<strong>b</strong> c d <strong>x y z</strong>",
-                          45) >= 0,
+              Str_Contains_Utf8(excerpt,
+                                "<strong>b</strong> c d <strong>x y z</strong>",
+                                45),
               "query with same word in both phrase and term doesn't cause freakout");
     DECREF(excerpt);
     DECREF(hit);
     DECREF(highlighter);
     DECREF(hits);
 
-    query = (Obj*)SSTR_WRAP_UTF8("blind", 5);
+    query = (Obj*)SSTR_WRAP_C("blind");
     hits = Searcher_Hits(searcher, query, 0, 10, NULL);
     highlighter = Highlighter_new(searcher, query, content, 200);
     hit = Hits_Next(hits);
     excerpt = Highlighter_Create_Excerpt(highlighter, hit);
     TEST_TRUE(runner,
-              Str_Find_Utf8(excerpt, "&quot;", 6) >= 0,
+              Str_Contains_Utf8(excerpt, "&quot;", 6),
               "HTML entity encoded properly");
     DECREF(excerpt);
     DECREF(hit);
     DECREF(highlighter);
     DECREF(hits);
 
-    query = (Obj*)SSTR_WRAP_UTF8("why", 3);
+    query = (Obj*)SSTR_WRAP_C("why");
     hits = Searcher_Hits(searcher, query, 0, 10, NULL);
     highlighter = Highlighter_new(searcher, query, content, 200);
     hit = Hits_Next(hits);
     excerpt = Highlighter_Create_Excerpt(highlighter, hit);
-    TEST_TRUE(runner,
-              Str_Find_Utf8(excerpt, "&#934;", 6) == -1,
-              "no ellipsis for short excerpt");
+    TEST_FALSE(runner,
+               Str_Contains_Utf8(excerpt, "&#934;", 6),
+               "no ellipsis for short excerpt");
     DECREF(excerpt);
     DECREF(hit);
     DECREF(highlighter);
     DECREF(hits);
 
-    Obj *term = (Obj*)SSTR_WRAP_UTF8("x", 1);
+    Obj *term = (Obj*)SSTR_WRAP_C("x");
     query = (Obj*)TermQuery_new(content, term);
     hits = Searcher_Hits(searcher, query, 0, 10, NULL);
     hit = Hits_Next(hits);
     highlighter = Highlighter_new(searcher, query, content, 200);
     excerpt = Highlighter_Create_Excerpt(highlighter, hit);
     TEST_TRUE(runner,
-              Str_Find_Utf8(excerpt, "strong", 5) >= 0,
+              Str_Contains_Utf8(excerpt, "strong", 5),
               "specify field highlights correct field...");
     DECREF(excerpt);
     DECREF(highlighter);
-    String *alt = (String*)SSTR_WRAP_UTF8("alt", 3);
+    String *alt = SSTR_WRAP_C("alt");
     highlighter = Highlighter_new(searcher, query, alt, 200);
     excerpt = Highlighter_Create_Excerpt(highlighter, hit);
-    TEST_TRUE(runner,
-              Str_Find_Utf8(excerpt, "strong", 5) == -1,
-              "... but not another field");
+    TEST_FALSE(runner,
+               Str_Contains_Utf8(excerpt, "strong", 5),
+               "... but not another field");
     DECREF(excerpt);
     DECREF(highlighter);
     DECREF(hit);
@@ -329,9 +329,9 @@ test_highlighting(TestBatchRunner *runner) {
     FullTextType *dunked_type = FullTextType_new((Analyzer*)tokenizer);
     FullTextType_Set_Highlightable(dunked_type, true);
     FullTextType_Set_Boost(dunked_type, 0.1f);
-    String *content = (String*)SSTR_WRAP_UTF8("content", 7);
+    String *content = SSTR_WRAP_C("content");
     Schema_Spec_Field(schema, content, (FieldType*)plain_type);
-    String *alt = (String*)SSTR_WRAP_UTF8("alt", 3);
+    String *alt = SSTR_WRAP_C("alt");
     Schema_Spec_Field(schema, alt, (FieldType*)dunked_type);
     DECREF(plain_type);
     DECREF(dunked_type);
@@ -341,23 +341,21 @@ test_highlighting(TestBatchRunner *runner) {
     Indexer *indexer = Indexer_new(schema, (Obj*)folder, NULL, 0);
 
     Doc *doc = Doc_new(NULL, 0);
-    String *string = (String *)SSTR_WRAP_UTF8(TEST_STRING, TEST_STRING_LEN);
+    String *string = SSTR_WRAP_C(TEST_STRING);
     Doc_Store(doc, content, (Obj*)string);
     Indexer_Add_Doc(indexer, doc, 1.0f);
     DECREF(doc);
 
     doc = Doc_new(NULL, 0);
-    string = (String *)SSTR_WRAP_UTF8("\"I see,\" said the blind man.", 28);
+    string = SSTR_WRAP_C("\"I see,\" said the blind man.");
     Doc_Store(doc, content, (Obj*)string);
     Indexer_Add_Doc(indexer, doc, 1.0f);
     DECREF(doc);
 
     doc = Doc_new(NULL, 0);
-    string = (String *)SSTR_WRAP_UTF8("x but not why or 2ee", 20);
+    string = SSTR_WRAP_C("x but not why or 2ee");
     Doc_Store(doc, content, (Obj*)string);
-    string = (String *)SSTR_WRAP_UTF8(TEST_STRING
-                                     " and extra stuff so it scores lower",
-                                     TEST_STRING_LEN + 35);
+    string = SSTR_WRAP_C(TEST_STRING " and extra stuff so it scores lower");
     Doc_Store(doc, alt, (Obj*)string);
     Indexer_Add_Doc(indexer, doc, 1.0f);
     DECREF(doc);
@@ -366,7 +364,7 @@ test_highlighting(TestBatchRunner *runner) {
     DECREF(indexer);
 
     Searcher *searcher = (Searcher*)IxSearcher_new((Obj*)folder);
-    Obj *query = (Obj*)SSTR_WRAP_UTF8("\"x y z\" AND " PHI, 14);
+    Obj *query = (Obj*)SSTR_WRAP_C("\"x y z\" AND " PHI);
     Hits *hits = Searcher_Hits(searcher, query, 0, 10, NULL);
 
     test_Raw_Excerpt(runner, searcher, query);
@@ -385,7 +383,7 @@ test_hl_selection(TestBatchRunner *runner) {
     StandardTokenizer *tokenizer = StandardTokenizer_new();
     FullTextType *plain_type = FullTextType_new((Analyzer*)tokenizer);
     FullTextType_Set_Highlightable(plain_type, true);
-    String *content = (String*)SSTR_WRAP_UTF8("content", 7);
+    String *content = SSTR_WRAP_C("content");
     Schema_Spec_Field(schema, content, (FieldType*)plain_type);
     DECREF(plain_type);
     DECREF(tokenizer);
@@ -408,7 +406,7 @@ test_hl_selection(TestBatchRunner *runner) {
         "bla bla bla bla bla bla bla bla bla bla bla bla bla bla bla bla. "
         "bla bla bla bla bla bla bla bla bla bla bla bla bla bla bla bla. ";
     Doc *doc = Doc_new(NULL, 0);
-    String *string = (String *)SSTR_WRAP_UTF8(test_string, strlen(test_string));
+    String *string = SSTR_WRAP_C(test_string);
     Doc_Store(doc, content, (Obj*)string);
     Indexer_Add_Doc(indexer, doc, 1.0f);
     DECREF(doc);
@@ -417,14 +415,14 @@ test_hl_selection(TestBatchRunner *runner) {
     DECREF(indexer);
 
     Searcher *searcher = (Searcher*)IxSearcher_new((Obj*)folder);
-    Obj *query = (Obj*)SSTR_WRAP_UTF8("NNN MMM", 7);
+    Obj *query = (Obj*)SSTR_WRAP_C("NNN MMM");
     Highlighter *highlighter = Highlighter_new(searcher, query, content, 200);
     Hits *hits = Searcher_Hits(searcher, query, 0, 10, NULL);
     HitDoc *hit = Hits_Next(hits);
     String *excerpt = Highlighter_Create_Excerpt(highlighter, hit);
-    String *mmm = (String*)SSTR_WRAP_UTF8("MMM", 3);
-    String *nnn = (String*)SSTR_WRAP_UTF8("NNN", 3);
-    TEST_TRUE(runner, Str_Find(excerpt, mmm) >= 0 || Str_Find(excerpt, nnn) >= 0,
+    String *mmm = SSTR_WRAP_C("MMM");
+    String *nnn = SSTR_WRAP_C("NNN");
+    TEST_TRUE(runner, Str_Contains(excerpt, mmm) || Str_Contains(excerpt, nnn),
               "Sentence boundary algo doesn't chop terms");
 
     DECREF(excerpt);
