@@ -18,6 +18,7 @@
 #define TESTLUCY_USE_SHORT_NAMES
 #include "Lucy/Util/ToolSet.h"
 
+#include "Clownfish/Blob.h"
 #include "Clownfish/TestHarness/TestBatchRunner.h"
 #include "Lucy/Test.h"
 #include "Lucy/Test/Store/TestFolder.h"
@@ -132,7 +133,7 @@ test_MkDir_and_Is_Directory(TestBatchRunner *runner) {
     TEST_FALSE(runner, Folder_MkDir(folder, foo_bar_baz),
                "MkDir for deeply nested dir fails");
     TEST_TRUE(runner, Err_get_error() != NULL,
-              "MkDir for deeply nested dir sets Err_error");
+              "MkDir for deeply nested dir sets global error");
 
     TEST_TRUE(runner, Folder_MkDir(folder, foo_bar),
               "MkDir for nested dir");
@@ -143,7 +144,7 @@ test_MkDir_and_Is_Directory(TestBatchRunner *runner) {
     TEST_FALSE(runner, Folder_MkDir(folder, foo_bar),
                "Overwrite dir with MkDir fails");
     TEST_TRUE(runner, Err_get_error() != NULL,
-              "Overwrite dir with MkDir sets Err_error");
+              "Overwrite dir with MkDir sets global error");
 
     fh = Folder_Open_FileHandle(folder, foo_boffo,
                                 FH_CREATE | FH_WRITE_ONLY);
@@ -152,7 +153,7 @@ test_MkDir_and_Is_Directory(TestBatchRunner *runner) {
     TEST_FALSE(runner, Folder_MkDir(folder, foo_boffo),
                "Overwrite file with MkDir fails");
     TEST_TRUE(runner, Err_get_error() != NULL,
-              "Overwrite file with MkDir sets Err_error");
+              "Overwrite file with MkDir sets global error");
     TEST_FALSE(runner, Folder_Is_Directory(folder, foo_boffo),
                "Is_Directory() false for nested file");
 
@@ -184,12 +185,12 @@ test_Enclosing_Folder_and_Find_Folder(TestBatchRunner *runner) {
         Folder *found = Folder_Find_Folder(folder, foo_bar);
         TEST_TRUE(runner,
                   encloser
-                  && Folder_Is_A(encloser, FOLDER)
+                  && Folder_is_a(encloser, FOLDER)
                   && Str_Ends_With(Folder_Get_Path(encloser), foo),
                   "Enclosing_Folder() - find one directory down");
         TEST_TRUE(runner,
                   found
-                  && Folder_Is_A(found, FOLDER)
+                  && Folder_is_a(found, FOLDER)
                   && Str_Ends_With(Folder_Get_Path(found), bar),
                   "Find_Folder() - 'foo/bar'");
     }
@@ -199,12 +200,12 @@ test_Enclosing_Folder_and_Find_Folder(TestBatchRunner *runner) {
         Folder *found = Folder_Find_Folder(folder, foo_bar_baz);
         TEST_TRUE(runner,
                   encloser
-                  && Folder_Is_A(encloser, FOLDER)
+                  && Folder_is_a(encloser, FOLDER)
                   && Str_Ends_With(Folder_Get_Path(encloser), bar),
                   "Find two directories down");
         TEST_TRUE(runner,
                   found
-                  && Folder_Is_A(found, FOLDER)
+                  && Folder_is_a(found, FOLDER)
                   && Str_Ends_With(Folder_Get_Path(found), baz),
                   "Find_Folder() - 'foo/bar/baz'");
     }
@@ -215,7 +216,7 @@ test_Enclosing_Folder_and_Find_Folder(TestBatchRunner *runner) {
         Folder *found = Folder_Find_Folder(folder, foo_bar_baz_boffo);
         TEST_TRUE(runner,
                   encloser
-                  && Folder_Is_A(encloser, FOLDER)
+                  && Folder_is_a(encloser, FOLDER)
                   && Str_Ends_With(Folder_Get_Path(encloser), baz),
                   "Recurse to find a directory containing a real file");
         TEST_TRUE(runner, found == NULL,
@@ -230,7 +231,7 @@ static void
 test_List(TestBatchRunner *runner) {
     Folder     *folder = (Folder*)RAMFolder_new(NULL);
     FileHandle *fh;
-    VArray     *list;
+    Vector     *list;
     String     *elem;
 
     Folder_MkDir(folder, foo);
@@ -242,21 +243,21 @@ test_List(TestBatchRunner *runner) {
     DECREF(fh);
 
     list = Folder_List(folder, NULL);
-    VA_Sort(list, NULL, NULL);
-    TEST_INT_EQ(runner, VA_Get_Size(list), 3, "List");
-    elem = (String*)DOWNCAST(VA_Fetch(list, 0), STRING);
+    Vec_Sort(list);
+    TEST_INT_EQ(runner, Vec_Get_Size(list), 3, "List");
+    elem = (String*)DOWNCAST(Vec_Fetch(list, 0), STRING);
     TEST_TRUE(runner, elem && Str_Equals(elem, (Obj*)banana),
               "List first file");
-    elem = (String*)DOWNCAST(VA_Fetch(list, 1), STRING);
+    elem = (String*)DOWNCAST(Vec_Fetch(list, 1), STRING);
     TEST_TRUE(runner, elem && Str_Equals(elem, (Obj*)boffo),
               "List second file");
-    elem = (String*)DOWNCAST(VA_Fetch(list, 2), STRING);
+    elem = (String*)DOWNCAST(Vec_Fetch(list, 2), STRING);
     TEST_TRUE(runner, elem && Str_Equals(elem, (Obj*)foo), "List dir");
     DECREF(list);
 
     list = Folder_List(folder, foo_bar);
-    TEST_INT_EQ(runner, VA_Get_Size(list), 1, "List subdirectory contents");
-    elem = (String*)DOWNCAST(VA_Fetch(list, 0), STRING);
+    TEST_INT_EQ(runner, Vec_Get_Size(list), 1, "List subdirectory contents");
+    elem = (String*)DOWNCAST(Vec_Fetch(list, 0), STRING);
     TEST_TRUE(runner, elem && Str_Equals(elem, (Obj*)baz),
               "Just the filename");
     DECREF(list);
@@ -273,10 +274,10 @@ test_Open_Dir(TestBatchRunner *runner) {
     Folder_MkDir(folder, foo_bar);
 
     dh = Folder_Open_Dir(folder, foo);
-    TEST_TRUE(runner, dh && DH_Is_A(dh, DIRHANDLE), "Open_Dir");
+    TEST_TRUE(runner, dh && DH_is_a(dh, DIRHANDLE), "Open_Dir");
     DECREF(dh);
     dh = Folder_Open_Dir(folder, foo_bar);
-    TEST_TRUE(runner, dh && DH_Is_A(dh, DIRHANDLE), "Open_Dir nested dir");
+    TEST_TRUE(runner, dh && DH_is_a(dh, DIRHANDLE), "Open_Dir nested dir");
     DECREF(dh);
 
     Err_set_error(NULL);
@@ -284,14 +285,14 @@ test_Open_Dir(TestBatchRunner *runner) {
     TEST_TRUE(runner, dh == NULL,
               "Open_Dir on non-existent entry fails");
     TEST_TRUE(runner, Err_get_error() != NULL,
-              "Open_Dir on non-existent entry sets Err_error");
+              "Open_Dir on non-existent entry sets global error");
 
     Err_set_error(NULL);
     dh = Folder_Open_Dir(folder, foo_foo);
     TEST_TRUE(runner, dh == NULL,
               "Open_Dir on non-existent nested entry fails");
     TEST_TRUE(runner, Err_get_error() != NULL,
-              "Open_Dir on non-existent nested entry sets Err_error");
+              "Open_Dir on non-existent nested entry sets global error");
 
     DECREF(folder);
 }
@@ -304,12 +305,12 @@ test_Open_FileHandle(TestBatchRunner *runner) {
     Folder_MkDir(folder, foo);
 
     fh = Folder_Open_FileHandle(folder, boffo, FH_CREATE | FH_WRITE_ONLY);
-    TEST_TRUE(runner, fh && FH_Is_A(fh, FILEHANDLE), "Open_FileHandle");
+    TEST_TRUE(runner, fh && FH_is_a(fh, FILEHANDLE), "Open_FileHandle");
     DECREF(fh);
 
     fh = Folder_Open_FileHandle(folder, foo_boffo,
                                 FH_CREATE | FH_WRITE_ONLY);
-    TEST_TRUE(runner, fh && FH_Is_A(fh, FILEHANDLE),
+    TEST_TRUE(runner, fh && FH_is_a(fh, FILEHANDLE),
               "Open_FileHandle for nested file");
     DECREF(fh);
 
@@ -318,7 +319,7 @@ test_Open_FileHandle(TestBatchRunner *runner) {
     TEST_TRUE(runner, fh == NULL,
               "Open_FileHandle on existing dir path fails");
     TEST_TRUE(runner, Err_get_error() != NULL,
-              "Open_FileHandle on existing dir name sets Err_error");
+              "Open_FileHandle on existing dir name sets global error");
 
     Err_set_error(NULL);
     fh = Folder_Open_FileHandle(folder, foo_bar_baz_boffo,
@@ -326,7 +327,7 @@ test_Open_FileHandle(TestBatchRunner *runner) {
     TEST_TRUE(runner, fh == NULL,
               "Open_FileHandle for entry within non-existent dir fails");
     TEST_TRUE(runner, Err_get_error() != NULL,
-              "Open_FileHandle for entry within non-existent dir sets Err_error");
+              "Open_FileHandle for entry within non-existent dir sets global error");
 
     DECREF(folder);
 }
@@ -339,12 +340,12 @@ test_Open_Out(TestBatchRunner *runner) {
     Folder_MkDir(folder, foo);
 
     outstream = Folder_Open_Out(folder, boffo);
-    TEST_TRUE(runner, outstream && OutStream_Is_A(outstream, OUTSTREAM),
+    TEST_TRUE(runner, outstream && OutStream_is_a(outstream, OUTSTREAM),
               "Open_Out");
     DECREF(outstream);
 
     outstream = Folder_Open_Out(folder, foo_boffo);
-    TEST_TRUE(runner, outstream && OutStream_Is_A(outstream, OUTSTREAM),
+    TEST_TRUE(runner, outstream && OutStream_is_a(outstream, OUTSTREAM),
               "Open_Out for nested file");
     DECREF(outstream);
 
@@ -353,21 +354,21 @@ test_Open_Out(TestBatchRunner *runner) {
     TEST_TRUE(runner, outstream == NULL,
               "Open_OutStream on existing file fails");
     TEST_TRUE(runner, Err_get_error() != NULL,
-              "Open_Out on existing file sets Err_error");
+              "Open_Out on existing file sets global error");
 
     Err_set_error(NULL);
     outstream = Folder_Open_Out(folder, foo);
     TEST_TRUE(runner, outstream == NULL,
               "Open_OutStream on existing dir path fails");
     TEST_TRUE(runner, Err_get_error() != NULL,
-              "Open_Out on existing dir name sets Err_error");
+              "Open_Out on existing dir name sets global error");
 
     Err_set_error(NULL);
     outstream = Folder_Open_Out(folder, foo_bar_baz_boffo);
     TEST_TRUE(runner, outstream == NULL,
               "Open_Out for entry within non-existent dir fails");
     TEST_TRUE(runner, Err_get_error() != NULL,
-              "Open_Out for entry within non-existent dir sets Err_error");
+              "Open_Out for entry within non-existent dir sets global error");
 
     DECREF(folder);
 }
@@ -386,12 +387,12 @@ test_Open_In(TestBatchRunner *runner) {
     DECREF(fh);
 
     instream = Folder_Open_In(folder, boffo);
-    TEST_TRUE(runner, instream && InStream_Is_A(instream, INSTREAM),
+    TEST_TRUE(runner, instream && InStream_is_a(instream, INSTREAM),
               "Open_In");
     DECREF(instream);
 
     instream = Folder_Open_In(folder, foo_boffo);
-    TEST_TRUE(runner, instream && InStream_Is_A(instream, INSTREAM),
+    TEST_TRUE(runner, instream && InStream_is_a(instream, INSTREAM),
               "Open_In for nested file");
     DECREF(instream);
 
@@ -400,14 +401,14 @@ test_Open_In(TestBatchRunner *runner) {
     TEST_TRUE(runner, instream == NULL,
               "Open_InStream on existing dir path fails");
     TEST_TRUE(runner, Err_get_error() != NULL,
-              "Open_In on existing dir name sets Err_error");
+              "Open_In on existing dir name sets global error");
 
     Err_set_error(NULL);
     instream = Folder_Open_In(folder, foo_bar_baz_boffo);
     TEST_TRUE(runner, instream == NULL,
               "Open_In for entry within non-existent dir fails");
     TEST_TRUE(runner, Err_get_error() != NULL,
-              "Open_In for entry within non-existent dir sets Err_error");
+              "Open_In for entry within non-existent dir sets global error");
 
     DECREF(folder);
 }
@@ -506,13 +507,13 @@ test_Slurp_File(TestBatchRunner *runner) {
     Folder *folder = (Folder*)RAMFolder_new(NULL);
     FileHandle *fh = Folder_Open_FileHandle(folder, foo,
                                             FH_CREATE | FH_WRITE_ONLY);
-    ByteBuf *contents;
+    Blob *contents;
 
     FH_Write(fh, "stuff", 5);
     FH_Close(fh);
     DECREF(fh);
     contents = Folder_Slurp_File(folder, foo);
-    TEST_TRUE(runner, BB_Equals_Bytes(contents, "stuff", 5), "Slurp_File");
+    TEST_TRUE(runner, Blob_Equals_Bytes(contents, "stuff", 5), "Slurp_File");
 
     DECREF(contents);
     DECREF(folder);
