@@ -137,8 +137,8 @@ test_Local_Find_Folder(TestBatchRunner *runner, set_up_t set_up,
     local = Folder_Local_Find_Folder(folder, nope);
     TEST_TRUE(runner, local == NULL, "Non-existent entry yields NULL");
 
-    StackString *empty = SSTR_BLANK();
-    local = Folder_Local_Find_Folder(folder, (String*)empty);
+    String *empty = SSTR_BLANK();
+    local = Folder_Local_Find_Folder(folder, empty);
     TEST_TRUE(runner, local == NULL, "Empty string yields NULL");
 
     local = Folder_Local_Find_Folder(folder, foo_bar);
@@ -156,7 +156,7 @@ test_Local_Find_Folder(TestBatchRunner *runner, set_up_t set_up,
     local = Folder_Local_Find_Folder(folder, foo);
     TEST_TRUE(runner,
               local
-              && Folder_Is_A(local, FOLDER)
+              && Folder_is_a(local, FOLDER)
               && Str_Ends_With(Folder_Get_Path(local), foo),
               "Find local directory");
 
@@ -181,7 +181,7 @@ test_Local_MkDir(TestBatchRunner *runner, set_up_t set_up, tear_down_t tear_down
     TEST_FALSE(runner, result,
                "Local_MkDir returns false when a dir already exists");
     TEST_TRUE(runner, Err_get_error() != NULL,
-              "Local_MkDir sets Err_error when a dir already exists");
+              "Local_MkDir sets global error when a dir already exists");
     TEST_TRUE(runner, Folder_Exists(folder, foo),
               "Existing dir untouched after failed Local_MkDir");
 
@@ -192,7 +192,7 @@ test_Local_MkDir(TestBatchRunner *runner, set_up_t set_up, tear_down_t tear_down
     TEST_FALSE(runner, result,
                "Local_MkDir returns false when a file already exists");
     TEST_TRUE(runner, Err_get_error() != NULL,
-              "Local_MkDir sets Err_error when a file already exists");
+              "Local_MkDir sets global error when a file already exists");
     TEST_TRUE(runner, Folder_Exists(folder, boffo) &&
               !Folder_Local_Is_Directory(folder, boffo),
               "Existing file untouched after failed Local_MkDir");
@@ -207,7 +207,7 @@ static void
 test_Local_Open_Dir(TestBatchRunner *runner, set_up_t set_up, tear_down_t tear_down) {
     Folder *folder = set_up();
     DirHandle *dh = Folder_Local_Open_Dir(folder);
-    TEST_TRUE(runner, dh && DH_Is_A(dh, DIRHANDLE),
+    TEST_TRUE(runner, dh && DH_is_a(dh, DIRHANDLE),
               "Local_Open_Dir returns an DirHandle");
     DECREF(dh);
     DECREF(folder);
@@ -222,13 +222,13 @@ test_Local_Open_FileHandle(TestBatchRunner *runner, set_up_t set_up,
 
     fh = Folder_Local_Open_FileHandle(folder, boffo,
                                       FH_CREATE | FH_WRITE_ONLY | FH_EXCLUSIVE);
-    TEST_TRUE(runner, fh && FH_Is_A(fh, FILEHANDLE),
+    TEST_TRUE(runner, fh && FH_is_a(fh, FILEHANDLE),
               "opened FileHandle");
     DECREF(fh);
 
     fh = Folder_Local_Open_FileHandle(folder, boffo,
                                       FH_CREATE | FH_WRITE_ONLY);
-    TEST_TRUE(runner, fh && FH_Is_A(fh, FILEHANDLE),
+    TEST_TRUE(runner, fh && FH_is_a(fh, FILEHANDLE),
               "opened FileHandle for append");
     DECREF(fh);
 
@@ -237,10 +237,10 @@ test_Local_Open_FileHandle(TestBatchRunner *runner, set_up_t set_up,
                                       FH_CREATE | FH_WRITE_ONLY | FH_EXCLUSIVE);
     TEST_TRUE(runner, fh == NULL, "FH_EXLUSIVE flag prevents clobber");
     TEST_TRUE(runner, Err_get_error() != NULL,
-              "failure due to FH_EXLUSIVE flag sets Err_error");
+              "failure due to FH_EXLUSIVE flag sets global error");
 
     fh = Folder_Local_Open_FileHandle(folder, boffo, FH_READ_ONLY);
-    TEST_TRUE(runner, fh && FH_Is_A(fh, FILEHANDLE),
+    TEST_TRUE(runner, fh && FH_is_a(fh, FILEHANDLE),
               "opened FileHandle for reading");
     DECREF(fh);
 
@@ -249,7 +249,7 @@ test_Local_Open_FileHandle(TestBatchRunner *runner, set_up_t set_up,
     TEST_TRUE(runner, fh == NULL,
               "Can't open non-existent file for reading");
     TEST_TRUE(runner, Err_get_error() != NULL,
-              "Opening non-existent file for reading sets Err_error");
+              "Opening non-existent file for reading sets global error");
 
     Folder_Delete(folder, boffo);
     DECREF(folder);
@@ -279,6 +279,7 @@ test_Local_Delete(TestBatchRunner *runner, set_up_t set_up, tear_down_t tear_dow
     Folder_Delete(folder, foo_boffo);
     TEST_TRUE(runner, Folder_Local_Delete(folder, foo),
               "Local_Delete on empty dir succeeds");
+    // FIXME: This test sometimes fails on Windows.
     TEST_FALSE(runner, Folder_Exists(folder, foo),
                "Dir is really gone");
 
@@ -371,7 +372,7 @@ test_Rename(TestBatchRunner *runner, set_up_t set_up, tear_down_t tear_down) {
     result = Folder_Rename(folder, foo_boffo, foo_bar);
     TEST_FALSE(runner, result, "Rename file clobbering dir fails");
     TEST_TRUE(runner, Err_get_error() != NULL,
-              "Failed rename sets Err_error");
+              "Failed rename sets global error");
     TEST_TRUE(runner, Folder_Exists(folder, foo_boffo),
               "File still exists at old path");
     TEST_TRUE(runner, Folder_Exists(folder, foo_bar),
@@ -381,7 +382,7 @@ test_Rename(TestBatchRunner *runner, set_up_t set_up, tear_down_t tear_down) {
     result = Folder_Rename(folder, foo_bar, foo_boffo);
     TEST_FALSE(runner, result, "Rename dir clobbering file fails");
     TEST_TRUE(runner, Err_get_error() != NULL,
-              "Failed rename sets Err_error");
+              "Failed rename sets global error");
     TEST_TRUE(runner, Folder_Exists(folder, foo_bar),
               "Dir still exists at old path");
     TEST_TRUE(runner, Folder_Exists(folder, foo_boffo),
@@ -395,6 +396,7 @@ test_Rename(TestBatchRunner *runner, set_up_t set_up, tear_down_t tear_down) {
               "File still exists");
 
     result = Folder_Rename(folder, foo_bar, foo_bar);
+    // FIXME: This test sometimes fails on Windows with "Permission denied".
     TEST_TRUE(runner, result, "Renaming dir to itself succeeds");
     TEST_TRUE(runner, Folder_Exists(folder, foo_bar),
               "Dir still exists");
@@ -405,7 +407,7 @@ test_Rename(TestBatchRunner *runner, set_up_t set_up, tear_down_t tear_down) {
     result = Folder_Rename(folder, foo_boffo, nope_nyet);
     TEST_FALSE(runner, result, "Rename into non-existent subdir fails");
     TEST_TRUE(runner, Err_get_error() != NULL,
-              "Renaming into non-existent subdir sets Err_error");
+              "Renaming into non-existent subdir sets global error");
     TEST_TRUE(runner, Folder_Exists(folder, foo_boffo),
               "Entry still exists at old path");
 
@@ -413,7 +415,7 @@ test_Rename(TestBatchRunner *runner, set_up_t set_up, tear_down_t tear_down) {
     result = Folder_Rename(folder, nope_nyet, boffo);
     TEST_FALSE(runner, result, "Rename non-existent file fails");
     TEST_TRUE(runner, Err_get_error() != NULL,
-              "Renaming non-existent source file sets Err_error");
+              "Renaming non-existent source file sets global error");
 
     Folder_Delete(folder, foo_bar_baz);
     Folder_Delete(folder, foo_bar);
@@ -488,6 +490,7 @@ test_Hard_Link(TestBatchRunner *runner, set_up_t set_up, tear_down_t tear_down)
     TEST_FALSE(runner, result, "Hard_Link dir fails");
     TEST_FALSE(runner, Folder_Exists(folder, banana),
                "Nothing at new path");
+    // FIXME: This test sometimes fails on Windows.
     TEST_TRUE(runner, Folder_Exists(folder, baz),
               "Folder still exists at old path");
     Folder_Delete(folder, baz);
@@ -505,7 +508,7 @@ test_Hard_Link(TestBatchRunner *runner, set_up_t set_up, tear_down_t tear_down)
     result = Folder_Rename(folder, foo_boffo, nope_nyet);
     TEST_FALSE(runner, result, "Hard_Link into non-existent subdir fails");
     TEST_TRUE(runner, Err_get_error() != NULL,
-              "Hard_Link into non-existent subdir sets Err_error");
+              "Hard_Link into non-existent subdir sets global error");
     TEST_TRUE(runner, Folder_Exists(folder, foo_boffo),
               "Entry still exists at old path");
 
@@ -513,7 +516,7 @@ test_Hard_Link(TestBatchRunner *runner, set_up_t set_up, tear_down_t tear_down)
     result = Folder_Rename(folder, nope_nyet, boffo);
     TEST_FALSE(runner, result, "Hard_Link non-existent source file fails");
     TEST_TRUE(runner, Err_get_error() != NULL,
-              "Hard_Link non-existent source file sets Err_error");
+              "Hard_Link non-existent source file sets global error");
 
     Folder_Delete(folder, foo_bar);
     Folder_Delete(folder, foo_boffo);
