@@ -33,7 +33,7 @@
 #include "Lucy/Store/OutStream.h"
 #include "Lucy/Store/RAMFile.h"
 #include "Lucy/Store/RAMFileHandle.h"
-#include "Clownfish/Util/NumberUtils.h"
+#include "Lucy/Util/NumberUtils.h"
 
 TestIOPrimitives*
 TestIOPrimitives_new() {
