@@ -57,11 +57,11 @@ IxFileNames_extract_gen(String *name) {
     // encounter a NULL.
     while (1) {
         int32_t code_point = StrIter_Next(iter);
-        if (code_point == STRITER_DONE) { return 0; }
+        if (code_point == STR_OOB) { return 0; }
         else if (code_point == '_') { break; }
     }
 
-    String *num_string = StrIter_substring(iter, NULL);
+    String *num_string = StrIter_crop(iter, NULL);
     uint64_t retval = (uint64_t)Str_BaseX_To_I64(num_string, 36);
 
     DECREF(num_string);
@@ -83,7 +83,7 @@ IxFileNames_local_part(String *path) {
     StrIter_Advance(tail, 1);
 
     // Substring should start after last slash.
-    while (code_point != STRITER_DONE) {
+    while (code_point != STR_OOB) {
         if (code_point == '/') {
             StrIter_Advance(top, 1);
             break;
@@ -91,7 +91,7 @@ IxFileNames_local_part(String *path) {
         code_point = StrIter_Prev(top);
     }
 
-    String *retval = StrIter_substring(top, tail);
+    String *retval = StrIter_crop(top, tail);
 
     DECREF(tail);
     DECREF(top);
