@@ -39,23 +39,24 @@
 #include "Lucy/Store/InStream.h"
 #include "Lucy/Store/OutStream.h"
 #include "Lucy/Util/Freezer.h"
+#include "Lucy/Util/Json.h"
 
 // Shared initialization routine which assumes that it's ok to assume control
 // over [field] and [terms], eating their refcounts.
 static ProximityQuery*
-S_do_init(ProximityQuery *self, String *field, VArray *terms, float boost,
+S_do_init(ProximityQuery *self, String *field, Vector *terms, float boost,
           uint32_t within);
 
 ProximityQuery*
-ProximityQuery_new(String *field, VArray *terms, uint32_t within) {
+ProximityQuery_new(String *field, Vector *terms, uint32_t within) {
     ProximityQuery *self = (ProximityQuery*)Class_Make_Obj(PROXIMITYQUERY);
     return ProximityQuery_init(self, field, terms, within);
 }
 
 ProximityQuery*
-ProximityQuery_init(ProximityQuery *self, String *field, VArray *terms,
+ProximityQuery_init(ProximityQuery *self, String *field, Vector *terms,
                     uint32_t within) {
-    return S_do_init(self, Str_Clone(field), VA_Clone(terms), 1.0f, within);
+    return S_do_init(self, Str_Clone(field), Vec_Clone(terms), 1.0f, within);
 }
 
 void
@@ -67,12 +68,12 @@ ProximityQuery_Destroy_IMP(ProximityQuery *self) {
 }
 
 static ProximityQuery*
-S_do_init(ProximityQuery *self, String *field, VArray *terms, float boost,
+S_do_init(ProximityQuery *self, String *field, Vector *terms, float boost,
           uint32_t within) {
     Query_init((Query*)self, boost);
     ProximityQueryIVARS *const ivars = ProximityQuery_IVARS(self);
-    for (uint32_t i = 0, max = VA_Get_Size(terms); i < max; i++) {
-        CERTIFY(VA_Fetch(terms, i), OBJ);
+    for (uint32_t i = 0, max = Vec_Get_Size(terms); i < max; i++) {
+        CERTIFY(Vec_Fetch(terms, i), OBJ);
     }
     ivars->field  = field;
     ivars->terms  = terms;
@@ -93,7 +94,7 @@ ProximityQuery*
 ProximityQuery_Deserialize_IMP(ProximityQuery *self, InStream *instream) {
     float boost = InStream_Read_F32(instream);
     String *field = Freezer_read_string(instream);
-    VArray *terms = Freezer_read_varray(instream);
+    Vector *terms = Freezer_read_varray(instream);
     uint32_t within = InStream_Read_C32(instream);
     return S_do_init(self, field, terms, boost, within);
 }
@@ -121,16 +122,16 @@ ProximityQuery_Load_IMP(ProximityQuery *self, Obj *dump) {
     Obj *field = CERTIFY(Hash_Fetch_Utf8(source, "field", 5), OBJ);
     loaded_ivars->field = (String*)CERTIFY(Freezer_load(field), STRING);
     Obj *terms = CERTIFY(Hash_Fetch_Utf8(source, "terms", 5), OBJ);
-    loaded_ivars->terms = (VArray*)CERTIFY(Freezer_load(terms), VARRAY);
+    loaded_ivars->terms = (Vector*)CERTIFY(Freezer_load(terms), VECTOR);
     Obj *within = CERTIFY(Hash_Fetch_Utf8(source, "within", 6), OBJ);
-    loaded_ivars->within = (uint32_t)Obj_To_I64(within);
+    loaded_ivars->within = (uint32_t)Json_obj_to_i64(within);
     return (Obj*)loaded;
 }
 
 bool
 ProximityQuery_Equals_IMP(ProximityQuery *self, Obj *other) {
     if ((ProximityQuery*)other == self)   { return true; }
-    if (!Obj_Is_A(other, PROXIMITYQUERY)) { return false; }
+    if (!Obj_is_a(other, PROXIMITYQUERY)) { return false; }
     ProximityQueryIVARS *const ivars = ProximityQuery_IVARS(self);
     ProximityQueryIVARS *const ovars
         = ProximityQuery_IVARS((ProximityQuery*)other);
@@ -141,7 +142,7 @@ ProximityQuery_Equals_IMP(ProximityQuery *self, Obj *other) {
     if (ivars->field && !Str_Equals(ivars->field, (Obj*)ovars->field)) {
         return false;
     }
-    if (!VA_Equals(ovars->terms, (Obj*)ivars->terms)) { return false; }
+    if (!Vec_Equals(ovars->terms, (Obj*)ivars->terms)) { return false; }
     if (ivars->within != ovars->within)               { return false; }
     return true;
 }
@@ -149,11 +150,12 @@ ProximityQuery_Equals_IMP(ProximityQuery *self, Obj *other) {
 String*
 ProximityQuery_To_String_IMP(ProximityQuery *self) {
     ProximityQueryIVARS *const ivars = ProximityQuery_IVARS(self);
-    uint32_t num_terms = VA_Get_Size(ivars->terms);
-    CharBuf *buf = CB_new_from_str(ivars->field);
+    uint32_t num_terms = Vec_Get_Size(ivars->terms);
+    CharBuf *buf = CB_new(0);
+    CB_Cat(buf, ivars->field);
     CB_Cat_Trusted_Utf8(buf, ":\"", 2);
     for (uint32_t i = 0; i < num_terms; i++) {
-        Obj *term = VA_Fetch(ivars->terms, i);
+        Obj *term = Vec_Fetch(ivars->terms, i);
         String *term_string = Obj_To_String(term);
         CB_Cat(buf, term_string);
         DECREF(term_string);
@@ -172,9 +174,9 @@ Compiler*
 ProximityQuery_Make_Compiler_IMP(ProximityQuery *self, Searcher *searcher,
                                  float boost, bool subordinate) {
     ProximityQueryIVARS *const ivars = ProximityQuery_IVARS(self);
-    if (VA_Get_Size(ivars->terms) == 1) {
+    if (Vec_Get_Size(ivars->terms) == 1) {
         // Optimize for one-term "phrases".
-        Obj *term = VA_Fetch(ivars->terms, 0);
+        Obj *term = Vec_Fetch(ivars->terms, 0);
         TermQuery *term_query = TermQuery_new(ivars->field, term);
         TermQuery_Set_Boost(term_query, ivars->boost);
         TermCompiler *term_compiler
@@ -198,7 +200,7 @@ ProximityQuery_Get_Field_IMP(ProximityQuery *self) {
     return ProximityQuery_IVARS(self)->field;
 }
 
-VArray*
+Vector*
 ProximityQuery_Get_Terms_IMP(ProximityQuery *self) {
     return ProximityQuery_IVARS(self)->terms;
 }
@@ -225,7 +227,7 @@ ProximityCompiler_init(ProximityCompiler *self, ProximityQuery *parent,
     ProximityQueryIVARS *const parent_ivars = ProximityQuery_IVARS(parent);
     Schema     *schema = Searcher_Get_Schema(searcher);
     Similarity *sim    = Schema_Fetch_Sim(schema, parent_ivars->field);
-    VArray     *terms  = parent_ivars->terms;
+    Vector     *terms  = parent_ivars->terms;
 
     ivars->within = within;
 
@@ -237,8 +239,8 @@ ProximityCompiler_init(ProximityCompiler *self, ProximityQuery *parent,
 
     // Store IDF for the phrase.
     ivars->idf = 0;
-    for (uint32_t i = 0, max = VA_Get_Size(terms); i < max; i++) {
-        Obj *term = VA_Fetch(terms, i);
+    for (uint32_t i = 0, max = Vec_Get_Size(terms); i < max; i++) {
+        Obj *term = Vec_Fetch(terms, i);
         int32_t doc_max  = Searcher_Doc_Max(searcher);
         int32_t doc_freq
             = Searcher_Doc_Freq(searcher, parent_ivars->field,term);
@@ -283,7 +285,7 @@ ProximityCompiler_Deserialize_IMP(ProximityCompiler *self,
 bool
 ProximityCompiler_Equals_IMP(ProximityCompiler *self, Obj *other) {
     if ((ProximityCompiler*)other == self)        { return true; }
-    if (!Obj_Is_A(other, PROXIMITYCOMPILER))      { return false; }
+    if (!Obj_is_a(other, PROXIMITYCOMPILER))      { return false; }
     ProximityCompiler_Equals_t super_equals
         = (ProximityCompiler_Equals_t)SUPER_METHOD_PTR(PROXIMITYCOMPILER,
                                                        LUCY_ProximityCompiler_Equals);
@@ -325,8 +327,8 @@ ProximityCompiler_Make_Matcher_IMP(ProximityCompiler *self, SegReader *reader,
     UNUSED_VAR(need_score);
     ProximityQueryIVARS *const parent_ivars
         = ProximityQuery_IVARS((ProximityQuery*)ivars->parent);
-    VArray *const      terms     = parent_ivars->terms;
-    uint32_t           num_terms = VA_Get_Size(terms);
+    Vector *const      terms     = parent_ivars->terms;
+    uint32_t           num_terms = Vec_Get_Size(terms);
 
     // Bail if there are no terms.
     if (!num_terms) { return NULL; }
@@ -334,7 +336,7 @@ ProximityCompiler_Make_Matcher_IMP(ProximityCompiler *self, SegReader *reader,
     // Bail unless field is valid and posting type supports positions.
     Similarity *sim     = ProximityCompiler_Get_Similarity(self);
     Posting    *posting = Sim_Make_Posting(sim);
-    if (posting == NULL || !Obj_Is_A((Obj*)posting, SCOREPOSTING)) {
+    if (posting == NULL || !Obj_is_a((Obj*)posting, SCOREPOSTING)) {
         DECREF(posting);
         return NULL;
     }
@@ -347,9 +349,9 @@ ProximityCompiler_Make_Matcher_IMP(ProximityCompiler *self, SegReader *reader,
     if (!plist_reader) { return NULL; }
 
     // Look up each term.
-    VArray  *plists = VA_new(num_terms);
+    Vector  *plists = Vec_new(num_terms);
     for (uint32_t i = 0; i < num_terms; i++) {
-        Obj *term = VA_Fetch(terms, i);
+        Obj *term = Vec_Fetch(terms, i);
         PostingList *plist
             = PListReader_Posting_List(plist_reader, parent_ivars->field, term);
 
@@ -359,7 +361,7 @@ ProximityCompiler_Make_Matcher_IMP(ProximityCompiler *self, SegReader *reader,
             DECREF(plists);
             return NULL;
         }
-        VA_Push(plists, (Obj*)plist);
+        Vec_Push(plists, (Obj*)plist);
     }
 
     Matcher *retval
@@ -368,27 +370,27 @@ ProximityCompiler_Make_Matcher_IMP(ProximityCompiler *self, SegReader *reader,
     return retval;
 }
 
-VArray*
+Vector*
 ProximityCompiler_Highlight_Spans_IMP(ProximityCompiler *self,
                                       Searcher *searcher, DocVector *doc_vec,
                                       String *field) {
     ProximityCompilerIVARS *const ivars = ProximityCompiler_IVARS(self);
     ProximityQueryIVARS *const parent_ivars
         = ProximityQuery_IVARS((ProximityQuery*)ivars->parent);
-    VArray         *const terms  = parent_ivars->terms;
-    VArray         *const spans  = VA_new(0);
-    const uint32_t  num_terms    = VA_Get_Size(terms);
+    Vector         *const terms  = parent_ivars->terms;
+    Vector         *const spans  = Vec_new(0);
+    const uint32_t  num_terms    = Vec_Get_Size(terms);
     UNUSED_VAR(searcher);
 
     // Bail if no terms or field doesn't match.
     if (!num_terms) { return spans; }
     if (!Str_Equals(field, (Obj*)parent_ivars->field)) { return spans; }
 
-    VArray      *term_vectors    = VA_new(num_terms);
+    Vector      *term_vectors    = Vec_new(num_terms);
     BitVector   *posit_vec       = BitVec_new(0);
     BitVector   *other_posit_vec = BitVec_new(0);
     for (uint32_t i = 0; i < num_terms; i++) {
-        Obj *term = VA_Fetch(terms, i);
+        Obj *term = Vec_Fetch(terms, i);
         TermVector *term_vector
             = DocVec_Term_Vector(doc_vec, field, (String*)term);
 
@@ -397,7 +399,7 @@ ProximityCompiler_Highlight_Spans_IMP(ProximityCompiler *self,
             break;
         }
 
-        VA_Push(term_vectors, (Obj*)term_vector);
+        Vec_Push(term_vectors, (Obj*)term_vector);
 
         if (i == 0) {
             // Set initial positions from first term.
@@ -422,11 +424,11 @@ ProximityCompiler_Highlight_Spans_IMP(ProximityCompiler *self,
     }
 
     // Proceed only if all terms are present.
-    uint32_t num_tvs = VA_Get_Size(term_vectors);
+    uint32_t num_tvs = Vec_Get_Size(term_vectors);
     if (num_tvs == num_terms) {
-        TermVector *first_tv = (TermVector*)VA_Fetch(term_vectors, 0);
+        TermVector *first_tv = (TermVector*)Vec_Fetch(term_vectors, 0);
         TermVector *last_tv
-            = (TermVector*)VA_Fetch(term_vectors, num_tvs - 1);
+            = (TermVector*)Vec_Fetch(term_vectors, num_tvs - 1);
         I32Array *tv_start_positions = TV_Get_Positions(first_tv);
         I32Array *tv_end_positions   = TV_Get_Positions(last_tv);
         I32Array *tv_start_offsets   = TV_Get_Start_Offsets(first_tv);
@@ -457,7 +459,7 @@ ProximityCompiler_Highlight_Spans_IMP(ProximityCompiler *self,
                 }
             }
 
-            VA_Push(spans, (Obj*)Span_new(start_offset,
+            Vec_Push(spans, (Obj*)Span_new(start_offset,
                                           end_offset - start_offset, weight));
 
             i++, j++;
