@@ -20,7 +20,7 @@
 #include "Lucy/Index/Inverter.h"
 #include "Lucy/Document/Doc.h"
 #include "Lucy/Index/Segment.h"
-#include "Clownfish/ByteBuf.h"
+#include "Clownfish/Blob.h"
 #include "Lucy/Plan/FieldType.h"
 #include "Lucy/Plan/BlobType.h"
 #include "Lucy/Plan/NumericType.h"
@@ -29,37 +29,20 @@
 #include "Clownfish/Util/StringHelper.h"
 
 static lucy_InverterEntry*
-S_fetch_entry(lucy_Inverter *self, HE *hash_entry) {
+S_fetch_entry(pTHX_ lucy_Inverter *self, HE *hash_entry) {
     lucy_InverterIVARS *const ivars = lucy_Inverter_IVARS(self);
     lucy_Schema *const schema = ivars->schema;
-    char *key;
-    STRLEN key_len;
-    STRLEN he_key_len = HeKLEN(hash_entry);
+    STRLEN key_size;
+    const char *key = XSBind_hash_key_to_utf8(aTHX_ hash_entry, &key_size);
 
-    // Force field name to UTF-8 if necessary.
-    if (he_key_len == (STRLEN)HEf_SVKEY) {
-        SV *key_sv = HeKEY_sv(hash_entry);
-        key = SvPVutf8(key_sv, key_len);
-    }
-    else {
-        key = HeKEY(hash_entry);
-        key_len = he_key_len;
-        if (!cfish_StrHelp_utf8_valid(key, key_len)) {
-            SV *key_sv = HeSVKEY_force(hash_entry);
-            key = SvPVutf8(key_sv, key_len);
-        }
-    }
-
-    cfish_StackString *field = CFISH_SSTR_WRAP_UTF8(key, key_len);
-    int32_t field_num
-        = LUCY_Seg_Field_Num(ivars->segment, (cfish_String*)field);
+    cfish_String *field = CFISH_SSTR_WRAP_UTF8(key, key_size);
+    int32_t field_num = LUCY_Seg_Field_Num(ivars->segment, field);
     if (!field_num) {
         // This field seems not to be in the segment yet.  Try to find it in
         // the Schema.
-        if (LUCY_Schema_Fetch_Type(schema, (cfish_String*)field)) {
+        if (LUCY_Schema_Fetch_Type(schema, field)) {
             // The field is in the Schema.  Get a field num from the Segment.
-            field_num = LUCY_Seg_Add_Field(ivars->segment,
-                                           (cfish_String*)field);
+            field_num = LUCY_Seg_Add_Field(ivars->segment, field);
         }
         else {
             // We've truly failed to find the field.  The user must
@@ -69,16 +52,17 @@ S_fetch_entry(lucy_Inverter *self, HE *hash_entry) {
     }
 
     lucy_InverterEntry *entry
-        = (lucy_InverterEntry*)CFISH_VA_Fetch(ivars->entry_pool, field_num);
+        = (lucy_InverterEntry*)CFISH_Vec_Fetch(ivars->entry_pool, field_num);
     if (!entry) {
-        entry = lucy_InvEntry_new(schema, (cfish_String*)field, field_num);
-        CFISH_VA_Store(ivars->entry_pool, field_num, (cfish_Obj*)entry);
+        entry = lucy_InvEntry_new(schema, field, field_num);
+        CFISH_Vec_Store(ivars->entry_pool, field_num, (cfish_Obj*)entry);
     }
     return entry;
 }
 
 void
 LUCY_Inverter_Invert_Doc_IMP(lucy_Inverter *self, lucy_Doc *doc) {
+    dTHX;
     HV  *const fields = (HV*)LUCY_Doc_Get_Fields(doc);
     I32  num_keys     = hv_iterinit(fields);
 
@@ -88,58 +72,53 @@ LUCY_Inverter_Invert_Doc_IMP(lucy_Inverter *self, lucy_Doc *doc) {
     // Extract and invert the doc's fields.
     while (num_keys--) {
         HE *hash_entry = hv_iternext(fields);
-        lucy_InverterEntry *inv_entry = S_fetch_entry(self, hash_entry);
+        lucy_InverterEntry *inv_entry = S_fetch_entry(aTHX_ self, hash_entry);
         SV *value_sv = HeVAL(hash_entry);
         lucy_InverterEntryIVARS *const entry_ivars
             = lucy_InvEntry_IVARS(inv_entry);
         lucy_FieldType *type = entry_ivars->type;
+        cfish_Obj *obj = NULL;
 
         // Get the field value, forcing text fields to UTF-8.
         switch (LUCY_FType_Primitive_ID(type) & lucy_FType_PRIMITIVE_ID_MASK) {
             case lucy_FType_TEXT: {
                     STRLEN val_len;
                     char *val_ptr = SvPVutf8(value_sv, val_len);
-                    CFISH_DECREF(entry_ivars->value);
-                    entry_ivars->value
-                        = (cfish_Obj*)cfish_Str_new_wrap_trusted_utf8(
-                                val_ptr, val_len);
+                    obj = (cfish_Obj*)cfish_Str_new_wrap_trusted_utf8(val_ptr,
+                                                                      val_len);
                     break;
                 }
             case lucy_FType_BLOB: {
                     STRLEN val_len;
                     char *val_ptr = SvPV(value_sv, val_len);
-                    cfish_ViewByteBuf *value
-                        = (cfish_ViewByteBuf*)entry_ivars->value;
-                    CFISH_ViewBB_Assign_Bytes(value, val_ptr, val_len);
+                    obj = (cfish_Obj*)cfish_Blob_new_wrap(val_ptr, val_len);
                     break;
                 }
             case lucy_FType_INT32: {
-                    cfish_Integer32* value = (cfish_Integer32*)entry_ivars->value;
-                    CFISH_Int32_Set_Value(value, SvIV(value_sv));
+                    obj = (cfish_Obj*)cfish_Int_new(SvIV(value_sv));
                     break;
                 }
             case lucy_FType_INT64: {
-                    cfish_Integer64* value = (cfish_Integer64*)entry_ivars->value;
+                    // nwellnhof: Using SvNOK could avoid a int/float/int
+                    // round-trip with 32-bit IVs.
                     int64_t val = sizeof(IV) == 8
                                   ? SvIV(value_sv)
                                   : (int64_t)SvNV(value_sv); // lossy
-                    CFISH_Int64_Set_Value(value, val);
-                    break;
-                }
-            case lucy_FType_FLOAT32: {
-                    cfish_Float32* value = (cfish_Float32*)entry_ivars->value;
-                    CFISH_Float32_Set_Value(value, (float)SvNV(value_sv));
+                    obj = (cfish_Obj*)cfish_Int_new(val);
                     break;
                 }
+            case lucy_FType_FLOAT32:
             case lucy_FType_FLOAT64: {
-                    cfish_Float64* value = (cfish_Float64*)entry_ivars->value;
-                    CFISH_Float64_Set_Value(value, SvNV(value_sv));
+                    obj = (cfish_Obj*)cfish_Float_new(SvNV(value_sv));
                     break;
                 }
             default:
                 THROW(CFISH_ERR, "Unrecognized type: %o", type);
         }
 
+        CFISH_DECREF(entry_ivars->value);
+        entry_ivars->value = obj;
+
         LUCY_Inverter_Add_Field(self, inv_entry);
     }
 }
